CallCreateNewStickerSet

Struct CallCreateNewStickerSet 

pub struct CallCreateNewStickerSet<'a> { /* private fields */ }

Implementations

Source

impl<'a> CallCreateNewStickerSet<'a>

pub fn user_id(self, user_id: i64) -> Self

User identifier of created sticker set owner

pub fn get_user_id(&'a self) -> &'a i64

pub fn name(self, name: &'a str) -> Self

Short name of sticker set, to be used in t.me/addstickers/ URLs (e.g., animals). Can contain only English letters, digits and underscores. Must begin with a letter, can’t contain consecutive underscores and must end in “by<bot_username>”. <bot_username> is case insensitive. 1-64 characters.

pub fn get_name(&'a self) -> &'a &'a str

pub fn title(self, title: &'a str) -> Self

Sticker set title, 1-64 characters

pub fn get_title(&'a self) -> &'a &'a str

pub fn stickers(self, stickers: &'a Vec<InputSticker>) -> Self

A JSON-serialized list of 1-50 initial stickers to be added to the sticker set

pub fn get_stickers(&'a self) -> &'a &'a Vec<InputSticker>

pub fn sticker_type(self, sticker_type: &'a str) -> Self

Type of stickers in the set, pass “regular”, “mask”, or “custom_emoji”. By default, a regular sticker set is created.

pub fn get_sticker_type(&'a self) -> &'a Option<&'a str>

pub fn needs_repainting(self, needs_repainting: bool) -> Self

Pass True if stickers in the sticker set must be repainted to the color of text when used in messages, the accent color if used as emoji status, white on chat photos, or another appropriate color based on context; for custom emoji sticker sets only

pub fn get_needs_repainting(&'a self) -> &'a Option<bool>

pub async fn build(self) -> BotResult<bool>