CallEditMessageCaption

Struct CallEditMessageCaption 

pub struct CallEditMessageCaption<'a, V> { /* private fields */ }

Implementations

Source

impl<'a, V: Into<ChatHandle> + Serialize> CallEditMessageCaption<'a, V>

pub fn business_connection_id(self, business_connection_id: &'a str) -> Self

Unique identifier of the business connection on behalf of which the message to be edited was sent

pub fn get_business_connection_id(&'a self) -> &'a Option<&'a str>

pub fn chat_id(self, chat_id: V) -> Self

Required if inline_message_id is not specified. Unique identifier for the target chat or username of the target channel (in the format @channelusername)

pub fn get_chat_id(&'a self) -> &'a Option<V>

pub fn message_id(self, message_id: i64) -> Self

Required if inline_message_id is not specified. Identifier of the message to edit

pub fn get_message_id(&'a self) -> &'a Option<i64>

pub fn inline_message_id(self, inline_message_id: &'a str) -> Self

Required if chat_id and message_id are not specified. Identifier of the inline message

pub fn get_inline_message_id(&'a self) -> &'a Option<&'a str>

pub fn caption(self, caption: &'a str) -> Self

New caption of the message, 0-1024 characters after entities parsing

pub fn get_caption(&'a self) -> &'a Option<&'a str>

pub fn parse_mode(self, parse_mode: &'a str) -> Self

Mode for parsing entities in the message caption. See formatting options for more details.

pub fn get_parse_mode(&'a self) -> &'a Option<&'a str>

pub fn caption_entities(self, caption_entities: &'a Vec<MessageEntity>) -> Self

A JSON-serialized list of special entities that appear in the caption, which can be specified instead of parse_mode

pub fn get_caption_entities(&'a self) -> &'a Option<&'a Vec<MessageEntity>>

pub fn show_caption_above_media(self, show_caption_above_media: bool) -> Self

Pass True, if the caption must be shown above the message media. Supported only for animation, photo and video messages.

pub fn get_show_caption_above_media(&'a self) -> &'a Option<bool>

pub fn reply_markup<T>(self, reply_markup: T) -> Self
where T: Into<&'a InlineKeyboardMarkup>,

A JSON-serialized object for an inline keyboard.

pub fn get_reply_markup(&'a self) -> &'a Option<&'a InlineKeyboardMarkup>

pub async fn build(self) -> BotResult<MessageBool>