pub struct CallReopenForumTopic<'a, V> { /* private fields */ }Implementations
Sourceimpl<'a, V: Into<ChatHandle> + Serialize> CallReopenForumTopic<'a, V>
impl<'a, V: Into<ChatHandle> + Serialize> CallReopenForumTopic<'a, V>
Sourcepub fn chat_id(self, chat_id: V) -> Self
pub fn chat_id(self, chat_id: V) -> Self
Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
pub fn get_chat_id(&'a self) -> &'a V
Sourcepub fn message_thread_id(self, message_thread_id: i64) -> Self
pub fn message_thread_id(self, message_thread_id: i64) -> Self
Unique identifier for the target message thread of the forum topic
pub fn get_message_thread_id(&'a self) -> &'a i64
pub async fn build(self) -> BotResult<bool>