Struct botapi::gen_methods::CallSetMyDescription
source · pub struct CallSetMyDescription<'a> { /* private fields */ }Implementations
sourceimpl<'a> CallSetMyDescription<'a>
impl<'a> CallSetMyDescription<'a>
sourcepub fn description(self, description: &'a str) -> Self
pub fn description(self, description: &'a str) -> Self
New bot description; 0-512 characters. Pass an empty string to remove the dedicated description for the given language.
pub fn get_description(&'a self) -> &'a Option<&'a str>
sourcepub fn language_code(self, language_code: &'a str) -> Self
pub fn language_code(self, language_code: &'a str) -> Self
A two-letter ISO 639-1 language code. If empty, the description will be applied to all users for whose language there is no dedicated description.
pub fn get_language_code(&'a self) -> &'a Option<&'a str>
pub async fn build(self) -> BotResult<bool>