CallSetWebhook

Struct CallSetWebhook 

pub struct CallSetWebhook<'a> { /* private fields */ }

Implementations

Source

impl<'a> CallSetWebhook<'a>

pub fn url(self, url: &'a str) -> Self

HTTPS URL to send updates to. Use an empty string to remove webhook integration

pub fn get_url(&'a self) -> &'a &'a str

pub fn certificate(self, certificate: FileData) -> Self

Upload your public key certificate so that the root certificate in use can be checked. See our self-signed guide for details.

pub fn get_certificate(&'a self) -> &'a Option<FileData>

pub fn ip_address(self, ip_address: &'a str) -> Self

The fixed IP address which will be used to send webhook requests instead of the IP address resolved through DNS

pub fn get_ip_address(&'a self) -> &'a Option<&'a str>

pub fn max_connections(self, max_connections: i64) -> Self

The maximum allowed number of simultaneous HTTPS connections to the webhook for update delivery, 1-100. Defaults to 40. Use lower values to limit the load on your bot’s server, and higher values to increase your bot’s throughput.

pub fn get_max_connections(&'a self) -> &'a Option<i64>

pub fn allowed_updates(self, allowed_updates: &'a Vec<String>) -> Self

A JSON-serialized list of the update types you want your bot to receive. For example, specify [“message”, “edited_channel_post”, “callback_query”] to only receive updates of these types. See Update for a complete list of available update types. Specify an empty list to receive all update types except chat_member, message_reaction, and message_reaction_count (default). If not specified, the previous setting will be used. Please note that this parameter doesn’t affect updates created before the call to the setWebhook, so unwanted updates may be received for a short period of time.

pub fn get_allowed_updates(&'a self) -> &'a Option<&'a Vec<String>>

pub fn drop_pending_updates(self, drop_pending_updates: bool) -> Self

Pass True to drop all pending updates

pub fn get_drop_pending_updates(&'a self) -> &'a Option<bool>

pub fn secret_token(self, secret_token: &'a str) -> Self

A secret token to be sent in a header “X-Telegram-Bot-Api-Secret-Token” in every webhook request, 1-256 characters. Only characters A-Z, a-z, 0-9, _ and - are allowed. The header is useful to ensure that the request comes from a webhook set by you.

pub fn get_secret_token(&'a self) -> &'a Option<&'a str>

pub async fn build(self) -> BotResult<bool>