Struct botapi::gen_types::BotCommand
source · pub struct BotCommand { /* private fields */ }Expand description
This object represents a bot command.
Implementations
sourceimpl BotCommand
impl BotCommand
pub fn noskip(self) -> NoSkipBotCommand
sourceimpl BotCommand
impl BotCommand
pub fn new(command: String, description: String) -> Self
sourcepub fn into_tuple(self) -> (String, String)
pub fn into_tuple(self) -> (String, String)
Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (command, description)
sourcepub fn get_command<'a>(&'a self) -> Cow<'a, str>
pub fn get_command<'a>(&'a self) -> Cow<'a, str>
Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.
sourcepub fn get_command_ref<'a>(&'a self) -> &'a str
pub fn get_command_ref<'a>(&'a self) -> &'a str
Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.
sourcepub fn set_command<'a>(&'a mut self, command: String) -> &'a mut Self
pub fn set_command<'a>(&'a mut self, command: String) -> &'a mut Self
Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.
sourcepub fn get_description<'a>(&'a self) -> Cow<'a, str>
pub fn get_description<'a>(&'a self) -> Cow<'a, str>
Description of the command; 1-256 characters.
sourcepub fn get_description_ref<'a>(&'a self) -> &'a str
pub fn get_description_ref<'a>(&'a self) -> &'a str
Description of the command; 1-256 characters.
sourcepub fn set_description<'a>(&'a mut self, description: String) -> &'a mut Self
pub fn set_description<'a>(&'a mut self, description: String) -> &'a mut Self
Description of the command; 1-256 characters.