pub struct BusinessMessagesDeletedBuilder {
pub business_connection_id: String,
pub chat: BoxWrapper<Unbox<Chat>>,
pub message_ids: Vec<i64>,
}Expand description
This object is received when messages are deleted from a connected business account.
Fields
business_connection_id: StringUnique identifier of the business connection
chat: BoxWrapper<Unbox<Chat>>Information about a chat in the business account. The bot may not have access to the chat or the corresponding user.
message_ids: Vec<i64>The list of identifiers of deleted messages in the chat of the business account
Implementations
Sourceimpl BusinessMessagesDeletedBuilder
impl BusinessMessagesDeletedBuilder
pub fn new<A: Into<Chat>>( business_connection_id: String, chat: A, message_ids: Vec<i64>, ) -> Self
Sourcepub fn set_business_connection_id(self, business_connection_id: String) -> Self
pub fn set_business_connection_id(self, business_connection_id: String) -> Self
Unique identifier of the business connection
Sourcepub fn set_chat(self, chat: Chat) -> Self
pub fn set_chat(self, chat: Chat) -> Self
Information about a chat in the business account. The bot may not have access to the chat or the corresponding user.
Sourcepub fn set_message_ids(self, message_ids: Vec<i64>) -> Self
pub fn set_message_ids(self, message_ids: Vec<i64>) -> Self
The list of identifiers of deleted messages in the chat of the business account
pub fn build(self) -> BusinessMessagesDeleted