pub struct BusinessOpeningHours {
pub time_zone_name: String,
pub opening_hours: Vec<BusinessOpeningHoursInterval>,
}Expand description
Describes the opening hours of a business.
Fields
time_zone_name: StringUnique name of the time zone for which the opening hours are defined
opening_hours: Vec<BusinessOpeningHoursInterval>List of time intervals describing business opening hours
Implementations
Sourceimpl BusinessOpeningHours
impl BusinessOpeningHours
pub fn noskip(self) -> NoSkipBusinessOpeningHours
Sourceimpl BusinessOpeningHours
impl BusinessOpeningHours
pub fn new( time_zone_name: String, opening_hours: Vec<BusinessOpeningHoursInterval>, ) -> Self
Sourcepub fn get_time_zone_name<'a>(&'a self) -> &'a str
pub fn get_time_zone_name<'a>(&'a self) -> &'a str
Unique name of the time zone for which the opening hours are defined
Sourcepub fn set_time_zone_name<'a>(
&'a mut self,
time_zone_name: String,
) -> &'a mut Self
pub fn set_time_zone_name<'a>( &'a mut self, time_zone_name: String, ) -> &'a mut Self
Unique name of the time zone for which the opening hours are defined
Sourcepub fn get_opening_hours<'a>(&'a self) -> &'a Vec<BusinessOpeningHoursInterval>
pub fn get_opening_hours<'a>(&'a self) -> &'a Vec<BusinessOpeningHoursInterval>
List of time intervals describing business opening hours
Sourcepub fn set_opening_hours<'a>(
&'a mut self,
opening_hours: Vec<BusinessOpeningHoursInterval>,
) -> &'a mut Self
pub fn set_opening_hours<'a>( &'a mut self, opening_hours: Vec<BusinessOpeningHoursInterval>, ) -> &'a mut Self
List of time intervals describing business opening hours