pub struct CallbackQueryBuilder {
pub id: String,
pub from: BoxWrapper<Unbox<User>>,
pub message: Option<BoxWrapper<Unbox<MaybeInaccessibleMessage>>>,
pub inline_message_id: Option<String>,
pub chat_instance: String,
pub data: Option<String>,
pub game_short_name: Option<String>,
}Expand description
This object represents an incoming callback query from a callback button in an inline keyboard. If the button that originated the query was attached to a message sent by the bot, the field message will be present. If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present. Exactly one of the fields data or game_short_name will be present.
Fields
id: StringUnique identifier for this query
from: BoxWrapper<Unbox<User>>Sender
message: Option<BoxWrapper<Unbox<MaybeInaccessibleMessage>>>Optional. Message sent by the bot with the callback button that originated the query
inline_message_id: Option<String>Optional. Identifier of the message sent via the bot in inline mode, that originated the query.
chat_instance: StringGlobal identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
data: Option<String>Optional. Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.
game_short_name: Option<String>Optional. Short name of a Game to be returned, serves as the unique identifier for the game
Implementations
Sourceimpl CallbackQueryBuilder
impl CallbackQueryBuilder
pub fn new<A: Into<User>>(id: String, from: A, chat_instance: String) -> Self
Sourcepub fn set_message(self, message: MaybeInaccessibleMessage) -> Self
pub fn set_message(self, message: MaybeInaccessibleMessage) -> Self
Optional. Message sent by the bot with the callback button that originated the query
Sourcepub fn set_inline_message_id(self, inline_message_id: String) -> Self
pub fn set_inline_message_id(self, inline_message_id: String) -> Self
Optional. Identifier of the message sent via the bot in inline mode, that originated the query.
Sourcepub fn set_chat_instance(self, chat_instance: String) -> Self
pub fn set_chat_instance(self, chat_instance: String) -> Self
Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
Sourcepub fn set_data(self, data: String) -> Self
pub fn set_data(self, data: String) -> Self
Optional. Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.
Sourcepub fn set_game_short_name(self, game_short_name: String) -> Self
pub fn set_game_short_name(self, game_short_name: String) -> Self
Optional. Short name of a Game to be returned, serves as the unique identifier for the game
pub fn build(self) -> CallbackQuery