pub struct ChatJoinRequestBuilder { /* private fields */ }
Represents a join request sent to a chat.

Implementations

source

impl ChatJoinRequestBuilder

source

pub fn new(chat: Chat, from: User, user_chat_id: i64, date: i64) -> Self

source

pub fn set_chat(self, chat: Chat) -> Self

Chat to which the request was sent

source

pub fn set_from(self, from: User) -> Self

User that sent the join request

source

pub fn set_user_chat_id(self, user_chat_id: i64) -> Self

Identifier of a private chat with the user who sent the join request. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot can use this identifier for 24 hours to send messages until the join request is processed, assuming no other administrator contacted the user.

source

pub fn set_date(self, date: i64) -> Self

Date the request was sent in Unix time

source

pub fn set_bio(self, bio: String) -> Self

Optional. Bio of the user.

Optional. Chat invite link that was used by the user to send the join request

source

pub fn build(self) -> ChatJoinRequest