pub struct ChecklistTasksAddedBuilder {
pub checklist_message: Option<BoxWrapper<Unbox<Message>>>,
pub tasks: Vec<ChecklistTask>,
}Expand description
Describes a service message about tasks added to a checklist.
Fields
checklist_message: Option<BoxWrapper<Unbox<Message>>>Optional. Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
tasks: Vec<ChecklistTask>List of tasks added to the checklist
Implementations
Sourceimpl ChecklistTasksAddedBuilder
impl ChecklistTasksAddedBuilder
pub fn new(tasks: Vec<ChecklistTask>) -> Self
Sourcepub fn set_checklist_message(self, checklist_message: Message) -> Self
pub fn set_checklist_message(self, checklist_message: Message) -> Self
Optional. Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Sourcepub fn set_tasks(self, tasks: Vec<ChecklistTask>) -> Self
pub fn set_tasks(self, tasks: Vec<ChecklistTask>) -> Self
List of tasks added to the checklist
pub fn build(self) -> ChecklistTasksAdded