pub struct Dice {
pub emoji: String,
pub value: i64,
}Expand description
This object represents an animated emoji that displays a random value.
Fields
emoji: StringEmoji on which the dice throw animation is based
value: i64Value of the dice, 1-6 for “🎲”, “🎯” and “🎳” base emoji, 1-5 for “🏀” and “⚽” base emoji, 1-64 for “🎰” base emoji
Implementations
Sourceimpl Dice
impl Dice
pub fn new(emoji: String, value: i64) -> Self
Sourcepub fn set_emoji<'a>(&'a mut self, emoji: String) -> &'a mut Self
pub fn set_emoji<'a>(&'a mut self, emoji: String) -> &'a mut Self
Emoji on which the dice throw animation is based