pub struct ForceReply {
pub force_reply: bool,
pub input_field_placeholder: Option<String>,
pub selective: Option<bool>,
}Expand description
Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot’s message and tapped ‘Reply’). This can be extremely useful if you want to create user-friendly step-by-step interfaces without having to sacrifice privacy mode. Not supported in channels and for messages sent on behalf of a Telegram Business account.
Fields
force_reply: boolShows reply interface to the user, as if they manually selected the bot’s message and tapped ‘Reply’
input_field_placeholder: Option<String>Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters
selective: Option<bool>Optional. Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.
Implementations
Sourceimpl ForceReply
impl ForceReply
pub fn noskip(self) -> NoSkipForceReply
Sourceimpl ForceReply
impl ForceReply
pub fn new(force_reply: bool) -> Self
Sourcepub fn get_force_reply<'a>(&'a self) -> bool
pub fn get_force_reply<'a>(&'a self) -> bool
Shows reply interface to the user, as if they manually selected the bot’s message and tapped ‘Reply’
Sourcepub fn set_force_reply<'a>(&'a mut self, force_reply: bool) -> &'a mut Self
pub fn set_force_reply<'a>(&'a mut self, force_reply: bool) -> &'a mut Self
Shows reply interface to the user, as if they manually selected the bot’s message and tapped ‘Reply’
Sourcepub fn get_input_field_placeholder<'a>(&'a self) -> Option<&'a str>
pub fn get_input_field_placeholder<'a>(&'a self) -> Option<&'a str>
Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters
Sourcepub fn set_input_field_placeholder<'a>(
&'a mut self,
input_field_placeholder: Option<String>,
) -> &'a mut Self
pub fn set_input_field_placeholder<'a>( &'a mut self, input_field_placeholder: Option<String>, ) -> &'a mut Self
Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters
Sourcepub fn get_selective<'a>(&'a self) -> Option<bool>
pub fn get_selective<'a>(&'a self) -> Option<bool>
Optional. Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.
Sourcepub fn set_selective<'a>(&'a mut self, selective: Option<bool>) -> &'a mut Self
pub fn set_selective<'a>(&'a mut self, selective: Option<bool>) -> &'a mut Self
Optional. Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.