pub struct GiveawayCreated {
pub prize_star_count: Option<i64>,
}Expand description
This object represents a service message about the creation of a scheduled giveaway.
Fields
prize_star_count: Option<i64>Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only
Implementations
Sourceimpl GiveawayCreated
impl GiveawayCreated
pub fn noskip(self) -> NoSkipGiveawayCreated
Sourceimpl GiveawayCreated
impl GiveawayCreated
pub fn new() -> Self
Sourcepub fn get_prize_star_count<'a>(&'a self) -> Option<i64>
pub fn get_prize_star_count<'a>(&'a self) -> Option<i64>
Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only
Sourcepub fn set_prize_star_count<'a>(
&'a mut self,
prize_star_count: Option<i64>,
) -> &'a mut Self
pub fn set_prize_star_count<'a>( &'a mut self, prize_star_count: Option<i64>, ) -> &'a mut Self
Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only