pub struct InlineKeyboardMarkup {
pub inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
}Expand description
This object represents an inline keyboard that appears right next to the message it belongs to.
Fields
inline_keyboard: Vec<Vec<InlineKeyboardButton>>Array of button rows, each represented by an Array of InlineKeyboardButton objects
Implementations
Sourceimpl InlineKeyboardMarkup
impl InlineKeyboardMarkup
pub fn noskip(self) -> NoSkipInlineKeyboardMarkup
Sourceimpl InlineKeyboardMarkup
impl InlineKeyboardMarkup
pub fn new(inline_keyboard: Vec<Vec<InlineKeyboardButton>>) -> Self
Sourcepub fn get_inline_keyboard<'a>(&'a self) -> &'a Vec<Vec<InlineKeyboardButton>>
pub fn get_inline_keyboard<'a>(&'a self) -> &'a Vec<Vec<InlineKeyboardButton>>
Array of button rows, each represented by an Array of InlineKeyboardButton objects
Sourcepub fn set_inline_keyboard<'a>(
&'a mut self,
inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
) -> &'a mut Self
pub fn set_inline_keyboard<'a>( &'a mut self, inline_keyboard: Vec<Vec<InlineKeyboardButton>>, ) -> &'a mut Self
Array of button rows, each represented by an Array of InlineKeyboardButton objects