InlineQuery

Struct InlineQuery 

pub struct InlineQuery {
    pub id: String,
    pub from: BoxWrapper<Unbox<User>>,
    pub query: String,
    pub offset: String,
    pub chat_type: Option<String>,
    pub location: Option<BoxWrapper<Unbox<Location>>>,
}
This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.

Fields

id: String

Unique identifier for this query

from: BoxWrapper<Unbox<User>>

Sender

query: String

Text of the query (up to 256 characters)

offset: String

Offset of the results to be returned, can be controlled by the bot

chat_type: Option<String>

Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat

location: Option<BoxWrapper<Unbox<Location>>>

Optional. Sender location, only for bots that request user location

Implementations

Source

impl InlineQuery

Source

impl InlineQuery

pub fn new<A: Into<User>>( id: String, from: A, query: String, offset: String, ) -> Self

pub fn get_id<'a>(&'a self) -> &'a str

Unique identifier for this query

pub fn set_id<'a>(&'a mut self, id: String) -> &'a mut Self

Unique identifier for this query

pub fn get_from<'a>(&'a self) -> &'a User

Sender

pub fn set_from<'a>(&'a mut self, from: User) -> &'a mut Self

Sender

pub fn get_query<'a>(&'a self) -> &'a str

Text of the query (up to 256 characters)

pub fn set_query<'a>(&'a mut self, query: String) -> &'a mut Self

Text of the query (up to 256 characters)

pub fn get_offset<'a>(&'a self) -> &'a str

Offset of the results to be returned, can be controlled by the bot

pub fn set_offset<'a>(&'a mut self, offset: String) -> &'a mut Self

Offset of the results to be returned, can be controlled by the bot

pub fn get_chat_type<'a>(&'a self) -> Option<&'a str>

Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat

pub fn set_chat_type<'a>( &'a mut self, chat_type: Option<String>, ) -> &'a mut Self

Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat

pub fn get_location<'a>(&'a self) -> Option<&'a Location>

Optional. Sender location, only for bots that request user location

pub fn set_location<'a>( &'a mut self, location: Option<Location>, ) -> &'a mut Self

Optional. Sender location, only for bots that request user location