Struct botapi::gen_types::InlineQueryResultAudioBuilder
source · pub struct InlineQueryResultAudioBuilder { /* private fields */ }Expand description
Represents a link to an MP3 audio file. By default, this audio file will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the audio.Note: This will only work in Telegram versions released after 9 April, 2016. Older clients will ignore them.
Implementations
sourceimpl InlineQueryResultAudioBuilder
impl InlineQueryResultAudioBuilder
pub fn new(id: String, audio_url: String, title: String) -> Self
sourcepub fn set_audio_url(self, audio_url: String) -> Self
pub fn set_audio_url(self, audio_url: String) -> Self
A valid URL for the audio file
sourcepub fn set_caption(self, caption: String) -> Self
pub fn set_caption(self, caption: String) -> Self
Optional. Caption, 0-1024 characters after entities parsing
sourcepub fn set_parse_mode(self, parse_mode: String) -> Self
pub fn set_parse_mode(self, parse_mode: String) -> Self
Optional. Mode for parsing entities in the audio caption. See formatting options for more details.
sourcepub fn set_caption_entities(self, caption_entities: Vec<MessageEntity>) -> Self
pub fn set_caption_entities(self, caption_entities: Vec<MessageEntity>) -> Self
Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
sourcepub fn set_performer(self, performer: String) -> Self
pub fn set_performer(self, performer: String) -> Self
Optional. Performer
sourcepub fn set_audio_duration(self, audio_duration: i64) -> Self
pub fn set_audio_duration(self, audio_duration: i64) -> Self
Optional. Audio duration in seconds
sourcepub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
pub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
Optional. Inline keyboard attached to the message
sourcepub fn set_input_message_content(
self,
input_message_content: InputMessageContent
) -> Self
pub fn set_input_message_content( self, input_message_content: InputMessageContent ) -> Self
Optional. Content of the message to be sent instead of the audio
pub fn build(self) -> InlineQueryResultAudio