Struct botapi::gen_types::InlineQueryResultCachedSticker
source · pub struct InlineQueryResultCachedSticker { /* private fields */ }Expand description
Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the sticker.Note: This will only work in Telegram versions released after 9 April, 2016 for static stickers and after 06 July, 2019 for animated stickers. Older clients will ignore them.
Implementations
sourceimpl InlineQueryResultCachedSticker
impl InlineQueryResultCachedSticker
pub fn noskip(self) -> NoSkipInlineQueryResultCachedSticker
sourceimpl InlineQueryResultCachedSticker
impl InlineQueryResultCachedSticker
pub fn new(id: String, sticker_file_id: String) -> Self
sourcepub fn into_tuple(
self
) -> (String, String, String, Option<InlineKeyboardMarkup>, Option<InputMessageContent>)
pub fn into_tuple( self ) -> (String, String, String, Option<InlineKeyboardMarkup>, Option<InputMessageContent>)
Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (type, id, sticker_file_id, reply_markup, input_message_content)
sourcepub fn get_tg_type<'a>(&'a self) -> Cow<'a, str>
pub fn get_tg_type<'a>(&'a self) -> Cow<'a, str>
Type of the result, must be sticker
sourcepub fn get_tg_type_ref<'a>(&'a self) -> &'a str
pub fn get_tg_type_ref<'a>(&'a self) -> &'a str
Type of the result, must be sticker
sourcepub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
pub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
Type of the result, must be sticker
sourcepub fn get_id_ref<'a>(&'a self) -> &'a str
pub fn get_id_ref<'a>(&'a self) -> &'a str
Unique identifier for this result, 1-64 bytes
sourcepub fn set_id<'a>(&'a mut self, id: String) -> &'a mut Self
pub fn set_id<'a>(&'a mut self, id: String) -> &'a mut Self
Unique identifier for this result, 1-64 bytes
sourcepub fn get_sticker_file_id<'a>(&'a self) -> Cow<'a, str>
pub fn get_sticker_file_id<'a>(&'a self) -> Cow<'a, str>
A valid file identifier of the sticker
sourcepub fn get_sticker_file_id_ref<'a>(&'a self) -> &'a str
pub fn get_sticker_file_id_ref<'a>(&'a self) -> &'a str
A valid file identifier of the sticker
sourcepub fn set_sticker_file_id<'a>(
&'a mut self,
sticker_file_id: String
) -> &'a mut Self
pub fn set_sticker_file_id<'a>( &'a mut self, sticker_file_id: String ) -> &'a mut Self
A valid file identifier of the sticker
sourcepub fn get_reply_markup<'a>(&'a self) -> Option<Cow<'a, InlineKeyboardMarkup>>
pub fn get_reply_markup<'a>(&'a self) -> Option<Cow<'a, InlineKeyboardMarkup>>
Optional. Inline keyboard attached to the message
sourcepub fn get_reply_markup_ref<'a>(&'a self) -> Option<&'a InlineKeyboardMarkup>
pub fn get_reply_markup_ref<'a>(&'a self) -> Option<&'a InlineKeyboardMarkup>
Optional. Inline keyboard attached to the message
sourcepub fn set_reply_markup<'a>(
&'a mut self,
reply_markup: Option<InlineKeyboardMarkup>
) -> &'a mut Self
pub fn set_reply_markup<'a>( &'a mut self, reply_markup: Option<InlineKeyboardMarkup> ) -> &'a mut Self
Optional. Inline keyboard attached to the message
sourcepub fn get_input_message_content<'a>(
&'a self
) -> Option<Cow<'a, InputMessageContent>>
pub fn get_input_message_content<'a>( &'a self ) -> Option<Cow<'a, InputMessageContent>>
Optional. Content of the message to be sent instead of the sticker
sourcepub fn get_input_message_content_ref<'a>(
&'a self
) -> Option<&'a InputMessageContent>
pub fn get_input_message_content_ref<'a>( &'a self ) -> Option<&'a InputMessageContent>
Optional. Content of the message to be sent instead of the sticker
sourcepub fn set_input_message_content<'a>(
&'a mut self,
input_message_content: Option<InputMessageContent>
) -> &'a mut Self
pub fn set_input_message_content<'a>( &'a mut self, input_message_content: Option<InputMessageContent> ) -> &'a mut Self
Optional. Content of the message to be sent instead of the sticker