pub struct InlineQueryResultCachedStickerBuilder { /* private fields */ }Expand description
Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the sticker.Note: This will only work in Telegram versions released after 9 April, 2016 for static stickers and after 06 July, 2019 for animated stickers. Older clients will ignore them.
Implementations
sourceimpl InlineQueryResultCachedStickerBuilder
impl InlineQueryResultCachedStickerBuilder
pub fn new(id: String, sticker_file_id: String) -> Self
sourcepub fn set_sticker_file_id(self, sticker_file_id: String) -> Self
pub fn set_sticker_file_id(self, sticker_file_id: String) -> Self
A valid file identifier of the sticker
sourcepub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
pub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
Optional. Inline keyboard attached to the message
sourcepub fn set_input_message_content(
self,
input_message_content: InputMessageContent
) -> Self
pub fn set_input_message_content( self, input_message_content: InputMessageContent ) -> Self
Optional. Content of the message to be sent instead of the sticker
pub fn build(self) -> InlineQueryResultCachedSticker