pub struct InlineQueryResultVenue {Show 15 fields
pub tg_type: String,
pub id: String,
pub latitude: OrderedFloat<f64>,
pub longitude: OrderedFloat<f64>,
pub title: String,
pub address: String,
pub foursquare_id: Option<String>,
pub foursquare_type: Option<String>,
pub google_place_id: Option<String>,
pub google_place_type: Option<String>,
pub reply_markup: Option<BoxWrapper<Unbox<InlineKeyboardMarkup>>>,
pub input_message_content: Option<BoxWrapper<Unbox<InputMessageContent>>>,
pub thumbnail_url: Option<String>,
pub thumbnail_width: Option<i64>,
pub thumbnail_height: Option<i64>,
}Expand description
Represents a venue. By default, the venue will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the venue.
Fields
tg_type: StringType of the result, must be venue
id: StringUnique identifier for this result, 1-64 Bytes
latitude: OrderedFloat<f64>Latitude of the venue location in degrees
longitude: OrderedFloat<f64>Longitude of the venue location in degrees
title: StringTitle of the venue
address: StringAddress of the venue
foursquare_id: Option<String>Optional. Foursquare identifier of the venue if known
foursquare_type: Option<String>Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
google_place_id: Option<String>Optional. Google Places identifier of the venue
google_place_type: Option<String>Optional. Google Places type of the venue. (See supported types.)
reply_markup: Option<BoxWrapper<Unbox<InlineKeyboardMarkup>>>Optional. Inline keyboard attached to the message
input_message_content: Option<BoxWrapper<Unbox<InputMessageContent>>>Optional. Content of the message to be sent instead of the venue
thumbnail_url: Option<String>Optional. Url of the thumbnail for the result
thumbnail_width: Option<i64>Optional. Thumbnail width
thumbnail_height: Option<i64>Optional. Thumbnail height
Implementations
Sourceimpl InlineQueryResultVenue
impl InlineQueryResultVenue
pub fn noskip(self) -> NoSkipInlineQueryResultVenue
Sourceimpl InlineQueryResultVenue
impl InlineQueryResultVenue
pub fn new( id: String, latitude: OrderedFloat<f64>, longitude: OrderedFloat<f64>, title: String, address: String, ) -> Self
Sourcepub fn get_tg_type<'a>(&'a self) -> &'a str
pub fn get_tg_type<'a>(&'a self) -> &'a str
Type of the result, must be venue
Sourcepub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
pub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
Type of the result, must be venue
Sourcepub fn set_id<'a>(&'a mut self, id: String) -> &'a mut Self
pub fn set_id<'a>(&'a mut self, id: String) -> &'a mut Self
Unique identifier for this result, 1-64 Bytes
Sourcepub fn get_latitude<'a>(&'a self) -> OrderedFloat<f64>
pub fn get_latitude<'a>(&'a self) -> OrderedFloat<f64>
Latitude of the venue location in degrees
Sourcepub fn set_latitude<'a>(
&'a mut self,
latitude: OrderedFloat<f64>,
) -> &'a mut Self
pub fn set_latitude<'a>( &'a mut self, latitude: OrderedFloat<f64>, ) -> &'a mut Self
Latitude of the venue location in degrees
Sourcepub fn get_longitude<'a>(&'a self) -> OrderedFloat<f64>
pub fn get_longitude<'a>(&'a self) -> OrderedFloat<f64>
Longitude of the venue location in degrees
Sourcepub fn set_longitude<'a>(
&'a mut self,
longitude: OrderedFloat<f64>,
) -> &'a mut Self
pub fn set_longitude<'a>( &'a mut self, longitude: OrderedFloat<f64>, ) -> &'a mut Self
Longitude of the venue location in degrees
Sourcepub fn get_address<'a>(&'a self) -> &'a str
pub fn get_address<'a>(&'a self) -> &'a str
Address of the venue
Sourcepub fn set_address<'a>(&'a mut self, address: String) -> &'a mut Self
pub fn set_address<'a>(&'a mut self, address: String) -> &'a mut Self
Address of the venue
Sourcepub fn get_foursquare_id<'a>(&'a self) -> Option<&'a str>
pub fn get_foursquare_id<'a>(&'a self) -> Option<&'a str>
Optional. Foursquare identifier of the venue if known
Sourcepub fn set_foursquare_id<'a>(
&'a mut self,
foursquare_id: Option<String>,
) -> &'a mut Self
pub fn set_foursquare_id<'a>( &'a mut self, foursquare_id: Option<String>, ) -> &'a mut Self
Optional. Foursquare identifier of the venue if known
Sourcepub fn get_foursquare_type<'a>(&'a self) -> Option<&'a str>
pub fn get_foursquare_type<'a>(&'a self) -> Option<&'a str>
Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
Sourcepub fn set_foursquare_type<'a>(
&'a mut self,
foursquare_type: Option<String>,
) -> &'a mut Self
pub fn set_foursquare_type<'a>( &'a mut self, foursquare_type: Option<String>, ) -> &'a mut Self
Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
Sourcepub fn get_google_place_id<'a>(&'a self) -> Option<&'a str>
pub fn get_google_place_id<'a>(&'a self) -> Option<&'a str>
Optional. Google Places identifier of the venue
Sourcepub fn set_google_place_id<'a>(
&'a mut self,
google_place_id: Option<String>,
) -> &'a mut Self
pub fn set_google_place_id<'a>( &'a mut self, google_place_id: Option<String>, ) -> &'a mut Self
Optional. Google Places identifier of the venue
Sourcepub fn get_google_place_type<'a>(&'a self) -> Option<&'a str>
pub fn get_google_place_type<'a>(&'a self) -> Option<&'a str>
Optional. Google Places type of the venue. (See supported types.)
Sourcepub fn set_google_place_type<'a>(
&'a mut self,
google_place_type: Option<String>,
) -> &'a mut Self
pub fn set_google_place_type<'a>( &'a mut self, google_place_type: Option<String>, ) -> &'a mut Self
Optional. Google Places type of the venue. (See supported types.)
Sourcepub fn get_reply_markup<'a>(&'a self) -> Option<&'a InlineKeyboardMarkup>
pub fn get_reply_markup<'a>(&'a self) -> Option<&'a InlineKeyboardMarkup>
Optional. Inline keyboard attached to the message
Sourcepub fn set_reply_markup<'a>(
&'a mut self,
reply_markup: Option<InlineKeyboardMarkup>,
) -> &'a mut Self
pub fn set_reply_markup<'a>( &'a mut self, reply_markup: Option<InlineKeyboardMarkup>, ) -> &'a mut Self
Optional. Inline keyboard attached to the message
Sourcepub fn get_input_message_content<'a>(
&'a self,
) -> Option<&'a InputMessageContent>
pub fn get_input_message_content<'a>( &'a self, ) -> Option<&'a InputMessageContent>
Optional. Content of the message to be sent instead of the venue
Sourcepub fn set_input_message_content<'a>(
&'a mut self,
input_message_content: Option<InputMessageContent>,
) -> &'a mut Self
pub fn set_input_message_content<'a>( &'a mut self, input_message_content: Option<InputMessageContent>, ) -> &'a mut Self
Optional. Content of the message to be sent instead of the venue
Sourcepub fn get_thumbnail_url<'a>(&'a self) -> Option<&'a str>
pub fn get_thumbnail_url<'a>(&'a self) -> Option<&'a str>
Optional. Url of the thumbnail for the result
Sourcepub fn set_thumbnail_url<'a>(
&'a mut self,
thumbnail_url: Option<String>,
) -> &'a mut Self
pub fn set_thumbnail_url<'a>( &'a mut self, thumbnail_url: Option<String>, ) -> &'a mut Self
Optional. Url of the thumbnail for the result
Sourcepub fn get_thumbnail_width<'a>(&'a self) -> Option<i64>
pub fn get_thumbnail_width<'a>(&'a self) -> Option<i64>
Optional. Thumbnail width
Sourcepub fn set_thumbnail_width<'a>(
&'a mut self,
thumbnail_width: Option<i64>,
) -> &'a mut Self
pub fn set_thumbnail_width<'a>( &'a mut self, thumbnail_width: Option<i64>, ) -> &'a mut Self
Optional. Thumbnail width
Sourcepub fn get_thumbnail_height<'a>(&'a self) -> Option<i64>
pub fn get_thumbnail_height<'a>(&'a self) -> Option<i64>
Optional. Thumbnail height
Sourcepub fn set_thumbnail_height<'a>(
&'a mut self,
thumbnail_height: Option<i64>,
) -> &'a mut Self
pub fn set_thumbnail_height<'a>( &'a mut self, thumbnail_height: Option<i64>, ) -> &'a mut Self
Optional. Thumbnail height