pub struct InlineQueryResultVenueBuilder {Show 15 fields
pub tg_type: String,
pub id: String,
pub latitude: OrderedFloat<f64>,
pub longitude: OrderedFloat<f64>,
pub title: String,
pub address: String,
pub foursquare_id: Option<String>,
pub foursquare_type: Option<String>,
pub google_place_id: Option<String>,
pub google_place_type: Option<String>,
pub reply_markup: Option<BoxWrapper<Unbox<InlineKeyboardMarkup>>>,
pub input_message_content: Option<BoxWrapper<Unbox<InputMessageContent>>>,
pub thumbnail_url: Option<String>,
pub thumbnail_width: Option<i64>,
pub thumbnail_height: Option<i64>,
}Expand description
Represents a venue. By default, the venue will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the venue.
Fields
tg_type: StringType of the result, must be venue
id: StringUnique identifier for this result, 1-64 Bytes
latitude: OrderedFloat<f64>Latitude of the venue location in degrees
longitude: OrderedFloat<f64>Longitude of the venue location in degrees
title: StringTitle of the venue
address: StringAddress of the venue
foursquare_id: Option<String>Optional. Foursquare identifier of the venue if known
foursquare_type: Option<String>Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
google_place_id: Option<String>Optional. Google Places identifier of the venue
google_place_type: Option<String>Optional. Google Places type of the venue. (See supported types.)
reply_markup: Option<BoxWrapper<Unbox<InlineKeyboardMarkup>>>Optional. Inline keyboard attached to the message
input_message_content: Option<BoxWrapper<Unbox<InputMessageContent>>>Optional. Content of the message to be sent instead of the venue
thumbnail_url: Option<String>Optional. Url of the thumbnail for the result
thumbnail_width: Option<i64>Optional. Thumbnail width
thumbnail_height: Option<i64>Optional. Thumbnail height
Implementations
Sourceimpl InlineQueryResultVenueBuilder
impl InlineQueryResultVenueBuilder
pub fn new( id: String, latitude: OrderedFloat<f64>, longitude: OrderedFloat<f64>, title: String, address: String, ) -> Self
Sourcepub fn set_latitude(self, latitude: OrderedFloat<f64>) -> Self
pub fn set_latitude(self, latitude: OrderedFloat<f64>) -> Self
Latitude of the venue location in degrees
Sourcepub fn set_longitude(self, longitude: OrderedFloat<f64>) -> Self
pub fn set_longitude(self, longitude: OrderedFloat<f64>) -> Self
Longitude of the venue location in degrees
Sourcepub fn set_address(self, address: String) -> Self
pub fn set_address(self, address: String) -> Self
Address of the venue
Sourcepub fn set_foursquare_id(self, foursquare_id: String) -> Self
pub fn set_foursquare_id(self, foursquare_id: String) -> Self
Optional. Foursquare identifier of the venue if known
Sourcepub fn set_foursquare_type(self, foursquare_type: String) -> Self
pub fn set_foursquare_type(self, foursquare_type: String) -> Self
Optional. Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
Sourcepub fn set_google_place_id(self, google_place_id: String) -> Self
pub fn set_google_place_id(self, google_place_id: String) -> Self
Optional. Google Places identifier of the venue
Sourcepub fn set_google_place_type(self, google_place_type: String) -> Self
pub fn set_google_place_type(self, google_place_type: String) -> Self
Optional. Google Places type of the venue. (See supported types.)
Sourcepub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
pub fn set_reply_markup(self, reply_markup: InlineKeyboardMarkup) -> Self
Optional. Inline keyboard attached to the message
Sourcepub fn set_input_message_content(
self,
input_message_content: InputMessageContent,
) -> Self
pub fn set_input_message_content( self, input_message_content: InputMessageContent, ) -> Self
Optional. Content of the message to be sent instead of the venue
Sourcepub fn set_thumbnail_url(self, thumbnail_url: String) -> Self
pub fn set_thumbnail_url(self, thumbnail_url: String) -> Self
Optional. Url of the thumbnail for the result
Sourcepub fn set_thumbnail_width(self, thumbnail_width: i64) -> Self
pub fn set_thumbnail_width(self, thumbnail_width: i64) -> Self
Optional. Thumbnail width
Sourcepub fn set_thumbnail_height(self, thumbnail_height: i64) -> Self
pub fn set_thumbnail_height(self, thumbnail_height: i64) -> Self
Optional. Thumbnail height
pub fn build(self) -> InlineQueryResultVenue