pub struct InputContactMessageContent {
pub phone_number: String,
pub first_name: String,
pub last_name: Option<String>,
pub vcard: Option<String>,
}Expand description
Represents the content of a contact message to be sent as the result of an inline query.
Fields
phone_number: StringContact’s phone number
first_name: StringContact’s first name
last_name: Option<String>Optional. Contact’s last name
vcard: Option<String>Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes
Implementations
Sourceimpl InputContactMessageContent
impl InputContactMessageContent
pub fn noskip(self) -> NoSkipInputContactMessageContent
Sourceimpl InputContactMessageContent
impl InputContactMessageContent
pub fn new(phone_number: String, first_name: String) -> Self
Sourcepub fn get_phone_number<'a>(&'a self) -> &'a str
pub fn get_phone_number<'a>(&'a self) -> &'a str
Contact’s phone number
Sourcepub fn set_phone_number<'a>(&'a mut self, phone_number: String) -> &'a mut Self
pub fn set_phone_number<'a>(&'a mut self, phone_number: String) -> &'a mut Self
Contact’s phone number
Sourcepub fn get_first_name<'a>(&'a self) -> &'a str
pub fn get_first_name<'a>(&'a self) -> &'a str
Contact’s first name
Sourcepub fn set_first_name<'a>(&'a mut self, first_name: String) -> &'a mut Self
pub fn set_first_name<'a>(&'a mut self, first_name: String) -> &'a mut Self
Contact’s first name
Sourcepub fn get_last_name<'a>(&'a self) -> Option<&'a str>
pub fn get_last_name<'a>(&'a self) -> Option<&'a str>
Optional. Contact’s last name
Sourcepub fn set_last_name<'a>(
&'a mut self,
last_name: Option<String>,
) -> &'a mut Self
pub fn set_last_name<'a>( &'a mut self, last_name: Option<String>, ) -> &'a mut Self
Optional. Contact’s last name