InputMediaVideo

Struct InputMediaVideo 

pub struct InputMediaVideo {
Show 14 fields pub tg_type: String, pub media: Option<InputFile>, pub thumbnail: Option<String>, pub cover: Option<String>, pub start_timestamp: Option<i64>, pub caption: Option<String>, pub parse_mode: Option<String>, pub caption_entities: Option<Vec<MessageEntity>>, pub show_caption_above_media: Option<bool>, pub width: Option<i64>, pub height: Option<i64>, pub duration: Option<i64>, pub supports_streaming: Option<bool>, pub has_spoiler: Option<bool>,
}
Represents a video to be sent.

Fields

tg_type: String

Type of the result, must be video

media: Option<InputFile>

File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

thumbnail: Option<String>

Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

cover: Option<String>

Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

start_timestamp: Option<i64>

Optional. Start timestamp for the video in the message

caption: Option<String>

Optional. Caption of the video to be sent, 0-1024 characters after entities parsing

parse_mode: Option<String>

Optional. Mode for parsing entities in the video caption. See formatting options for more details.

caption_entities: Option<Vec<MessageEntity>>

Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode

show_caption_above_media: Option<bool>

Optional. Pass True, if the caption must be shown above the message media

width: Option<i64>

Optional. Video width

height: Option<i64>

Optional. Video height

duration: Option<i64>

Optional. Video duration in seconds

supports_streaming: Option<bool>

Optional. Pass True if the uploaded video is suitable for streaming

has_spoiler: Option<bool>

Optional. Pass True if the video needs to be covered with a spoiler animation

Implementations

Source

impl InputMediaVideo

Source

impl InputMediaVideo

pub fn new(media: Option<InputFile>) -> Self

pub fn get_tg_type<'a>(&'a self) -> &'a str

Type of the result, must be video

pub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self

Type of the result, must be video

pub fn get_media<'a>(&'a self) -> &'a Option<InputFile>

File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn set_media<'a>(&'a mut self, media: Option<InputFile>) -> &'a mut Self

File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn get_thumbnail<'a>(&'a self) -> Option<&'a str>

Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn set_thumbnail<'a>( &'a mut self, thumbnail: Option<String>, ) -> &'a mut Self

Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn get_cover<'a>(&'a self) -> Option<&'a str>

Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn set_cover<'a>(&'a mut self, cover: Option<String>) -> &'a mut Self

Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

pub fn get_start_timestamp<'a>(&'a self) -> Option<i64>

Optional. Start timestamp for the video in the message

pub fn set_start_timestamp<'a>( &'a mut self, start_timestamp: Option<i64>, ) -> &'a mut Self

Optional. Start timestamp for the video in the message

pub fn get_caption<'a>(&'a self) -> Option<&'a str>

Optional. Caption of the video to be sent, 0-1024 characters after entities parsing

pub fn set_caption<'a>(&'a mut self, caption: Option<String>) -> &'a mut Self

Optional. Caption of the video to be sent, 0-1024 characters after entities parsing

pub fn get_parse_mode<'a>(&'a self) -> Option<&'a str>

Optional. Mode for parsing entities in the video caption. See formatting options for more details.

pub fn set_parse_mode<'a>( &'a mut self, parse_mode: Option<String>, ) -> &'a mut Self

Optional. Mode for parsing entities in the video caption. See formatting options for more details.

pub fn get_caption_entities<'a>(&'a self) -> Option<&'a Vec<MessageEntity>>

Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode

pub fn set_caption_entities<'a>( &'a mut self, caption_entities: Option<Vec<MessageEntity>>, ) -> &'a mut Self

Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode

pub fn get_show_caption_above_media<'a>(&'a self) -> Option<bool>

Optional. Pass True, if the caption must be shown above the message media

pub fn set_show_caption_above_media<'a>( &'a mut self, show_caption_above_media: Option<bool>, ) -> &'a mut Self

Optional. Pass True, if the caption must be shown above the message media

pub fn get_width<'a>(&'a self) -> Option<i64>

Optional. Video width

pub fn set_width<'a>(&'a mut self, width: Option<i64>) -> &'a mut Self

Optional. Video width

pub fn get_height<'a>(&'a self) -> Option<i64>

Optional. Video height

pub fn set_height<'a>(&'a mut self, height: Option<i64>) -> &'a mut Self

Optional. Video height

pub fn get_duration<'a>(&'a self) -> Option<i64>

Optional. Video duration in seconds

pub fn set_duration<'a>(&'a mut self, duration: Option<i64>) -> &'a mut Self

Optional. Video duration in seconds

pub fn get_supports_streaming<'a>(&'a self) -> Option<bool>

Optional. Pass True if the uploaded video is suitable for streaming

pub fn set_supports_streaming<'a>( &'a mut self, supports_streaming: Option<bool>, ) -> &'a mut Self

Optional. Pass True if the uploaded video is suitable for streaming

pub fn get_has_spoiler<'a>(&'a self) -> Option<bool>

Optional. Pass True if the video needs to be covered with a spoiler animation

pub fn set_has_spoiler<'a>( &'a mut self, has_spoiler: Option<bool>, ) -> &'a mut Self

Optional. Pass True if the video needs to be covered with a spoiler animation