pub struct InputProfilePhotoAnimatedBuilder {
pub tg_type: String,
pub animation: String,
pub main_frame_timestamp: Option<OrderedFloat<f64>>,
}Expand description
An animated profile photo in the MPEG4 format.
Fields
tg_type: StringType of the profile photo, must be animated
animation: StringThe animated profile photo. Profile photos can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files
main_frame_timestamp: Option<OrderedFloat<f64>>Optional. Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.
Implementations
Sourceimpl InputProfilePhotoAnimatedBuilder
impl InputProfilePhotoAnimatedBuilder
pub fn new(animation: String) -> Self
Sourcepub fn set_animation(self, animation: String) -> Self
pub fn set_animation(self, animation: String) -> Self
The animated profile photo. Profile photos can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files
Sourcepub fn set_main_frame_timestamp(
self,
main_frame_timestamp: OrderedFloat<f64>,
) -> Self
pub fn set_main_frame_timestamp( self, main_frame_timestamp: OrderedFloat<f64>, ) -> Self
Optional. Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.
pub fn build(self) -> InputProfilePhotoAnimated