pub struct InputTextMessageContentBuilder {
pub message_text: String,
pub parse_mode: Option<String>,
pub entities: Option<Vec<MessageEntity>>,
pub link_preview_options: Option<BoxWrapper<Unbox<LinkPreviewOptions>>>,
}Expand description
Represents the content of a text message to be sent as the result of an inline query.
Fields
message_text: StringText of the message to be sent, 1-4096 characters
parse_mode: Option<String>Optional. Mode for parsing entities in the message text. See formatting options for more details.
entities: Option<Vec<MessageEntity>>Optional. List of special entities that appear in message text, which can be specified instead of parse_mode
link_preview_options: Option<BoxWrapper<Unbox<LinkPreviewOptions>>>Optional. Link preview generation options for the message
Implementations
Sourceimpl InputTextMessageContentBuilder
impl InputTextMessageContentBuilder
pub fn new(message_text: String) -> Self
Sourcepub fn set_message_text(self, message_text: String) -> Self
pub fn set_message_text(self, message_text: String) -> Self
Text of the message to be sent, 1-4096 characters
Sourcepub fn set_parse_mode(self, parse_mode: String) -> Self
pub fn set_parse_mode(self, parse_mode: String) -> Self
Optional. Mode for parsing entities in the message text. See formatting options for more details.
Sourcepub fn set_entities(self, entities: Vec<MessageEntity>) -> Self
pub fn set_entities(self, entities: Vec<MessageEntity>) -> Self
Optional. List of special entities that appear in message text, which can be specified instead of parse_mode
Sourcepub fn set_link_preview_options(
self,
link_preview_options: LinkPreviewOptions,
) -> Self
pub fn set_link_preview_options( self, link_preview_options: LinkPreviewOptions, ) -> Self
Optional. Link preview generation options for the message
pub fn build(self) -> InputTextMessageContent