pub struct KeyboardButtonPollTypeBuilder {
pub tg_type: Option<String>,
}Expand description
This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.
Fields
tg_type: Option<String>Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.
Implementations
Sourceimpl KeyboardButtonPollTypeBuilder
impl KeyboardButtonPollTypeBuilder
pub fn new() -> Self
Sourcepub fn set_type(self, tg_type: String) -> Self
pub fn set_type(self, tg_type: String) -> Self
Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.
pub fn build(self) -> KeyboardButtonPollType