pub struct MessageOriginChannelBuilder {
pub tg_type: String,
pub date: i64,
pub chat: BoxWrapper<Unbox<Chat>>,
pub message_id: i64,
pub author_signature: Option<String>,
}Expand description
The message was originally sent to a channel chat.
Fields
tg_type: StringType of the message origin, always “channel”
date: i64Date the message was sent originally in Unix time
chat: BoxWrapper<Unbox<Chat>>Channel chat to which the message was originally sent
message_id: i64Unique message identifier inside the chat
Optional. Signature of the original post author
Implementations
Sourceimpl MessageOriginChannelBuilder
impl MessageOriginChannelBuilder
pub fn new<A: Into<Chat>>(date: i64, chat: A, message_id: i64) -> Self
Sourcepub fn set_chat(self, chat: Chat) -> Self
pub fn set_chat(self, chat: Chat) -> Self
Channel chat to which the message was originally sent
Sourcepub fn set_message_id(self, message_id: i64) -> Self
pub fn set_message_id(self, message_id: i64) -> Self
Unique message identifier inside the chat
Optional. Signature of the original post author
pub fn build(self) -> MessageOriginChannel