pub struct NoSkipChatShared {
pub request_id: i64,
pub chat_id: i64,
pub title: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
Companion type to ChatShared that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
request_id: i64Identifier of the request
chat_id: i64Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.
title: Option<String>username: Option<String>photo: Option<Vec<PhotoSize>>Implementations
pub fn skip(self) -> ChatShared