pub struct NoSkipChosenInlineResult {
pub result_id: String,
pub from: BoxWrapper<Unbox<User>>,
pub location: Option<BoxWrapper<Unbox<Location>>>,
pub inline_message_id: Option<String>,
pub query: String,
}Expand description
Companion type to ChosenInlineResult that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
result_id: StringThe unique identifier for the result that was chosen
from: BoxWrapper<Unbox<User>>The user that chose the result
location: Option<BoxWrapper<Unbox<Location>>>inline_message_id: Option<String>query: StringThe query that was used to obtain the result
Implementations
Sourceimpl NoSkipChosenInlineResult
impl NoSkipChosenInlineResult
pub fn skip(self) -> ChosenInlineResult