pub struct NoSkipGame {
pub title: String,
pub description: String,
pub photo: Vec<PhotoSize>,
pub text: Option<String>,
pub text_entities: Option<Vec<MessageEntity>>,
pub animation: Option<BoxWrapper<Unbox<Animation>>>,
}Expand description
Companion type to Game that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
title: StringTitle of the game
description: StringDescription of the game
photo: Vec<PhotoSize>Photo that will be displayed in the game message in chats.
text: Option<String>text_entities: Option<Vec<MessageEntity>>animation: Option<BoxWrapper<Unbox<Animation>>>Implementations