pub struct NoSkipSharedUser {
pub user_id: i64,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
Companion type to SharedUser that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
user_id: i64Identifier of the shared user. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so 64-bit integers or double-precision float types are safe for storing these identifiers. The bot may not have access to the user and could be unable to use this identifier, unless the user is already known to the bot by some other means.
first_name: Option<String>last_name: Option<String>username: Option<String>photo: Option<Vec<PhotoSize>>Implementations
pub fn skip(self) -> SharedUser