pub struct NoSkipUserProfilePhotos {
pub total_count: i64,
pub photos: Vec<Vec<PhotoSize>>,
}Expand description
Companion type to UserProfilePhotos that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
total_count: i64Total number of profile pictures the target user has
photos: Vec<Vec<PhotoSize>>Requested profile pictures (in up to 4 sizes each)
Implementations
Sourceimpl NoSkipUserProfilePhotos
impl NoSkipUserProfilePhotos
pub fn skip(self) -> UserProfilePhotos