pub struct NoSkipWebhookInfo {
pub url: String,
pub has_custom_certificate: bool,
pub pending_update_count: i64,
pub ip_address: Option<String>,
pub last_error_date: Option<i64>,
pub last_error_message: Option<String>,
pub last_synchronization_error_date: Option<i64>,
pub max_connections: Option<i64>,
pub allowed_updates: Option<Vec<String>>,
}Expand description
Companion type to WebhookInfo that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
url: StringWebhook URL, may be empty if webhook is not set up
has_custom_certificate: boolTrue, if a custom certificate was provided for webhook certificate checks
pending_update_count: i64Number of updates awaiting delivery
ip_address: Option<String>last_error_date: Option<i64>last_error_message: Option<String>last_synchronization_error_date: Option<i64>max_connections: Option<i64>allowed_updates: Option<Vec<String>>Implementations
Sourceimpl NoSkipWebhookInfo
impl NoSkipWebhookInfo
pub fn skip(self) -> WebhookInfo