pub struct PaidMediaPreview {
pub tg_type: String,
pub width: Option<i64>,
pub height: Option<i64>,
pub duration: Option<i64>,
}Expand description
The paid media isn’t available before the payment.
Fields
tg_type: StringType of the paid media, always “preview”
width: Option<i64>Optional. Media width as defined by the sender
height: Option<i64>Optional. Media height as defined by the sender
duration: Option<i64>Optional. Duration of the media in seconds as defined by the sender
Implementations
Sourceimpl PaidMediaPreview
impl PaidMediaPreview
pub fn noskip(self) -> NoSkipPaidMediaPreview
Sourceimpl PaidMediaPreview
impl PaidMediaPreview
pub fn new() -> Self
Sourcepub fn get_tg_type<'a>(&'a self) -> &'a str
pub fn get_tg_type<'a>(&'a self) -> &'a str
Type of the paid media, always “preview”
Sourcepub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
pub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
Type of the paid media, always “preview”
Sourcepub fn set_width<'a>(&'a mut self, width: Option<i64>) -> &'a mut Self
pub fn set_width<'a>(&'a mut self, width: Option<i64>) -> &'a mut Self
Optional. Media width as defined by the sender
Sourcepub fn get_height<'a>(&'a self) -> Option<i64>
pub fn get_height<'a>(&'a self) -> Option<i64>
Optional. Media height as defined by the sender
Sourcepub fn set_height<'a>(&'a mut self, height: Option<i64>) -> &'a mut Self
pub fn set_height<'a>(&'a mut self, height: Option<i64>) -> &'a mut Self
Optional. Media height as defined by the sender
Sourcepub fn get_duration<'a>(&'a self) -> Option<i64>
pub fn get_duration<'a>(&'a self) -> Option<i64>
Optional. Duration of the media in seconds as defined by the sender
Sourcepub fn set_duration<'a>(&'a mut self, duration: Option<i64>) -> &'a mut Self
pub fn set_duration<'a>(&'a mut self, duration: Option<i64>) -> &'a mut Self
Optional. Duration of the media in seconds as defined by the sender