Struct botapi::gen_types::PassportElementErrorReverseSide
source · pub struct PassportElementErrorReverseSide { /* private fields */ }Expand description
Represents an issue with the reverse side of a document. The error is considered resolved when the file with reverse side of the document changes.
Implementations
sourceimpl PassportElementErrorReverseSide
impl PassportElementErrorReverseSide
pub fn noskip(self) -> NoSkipPassportElementErrorReverseSide
sourceimpl PassportElementErrorReverseSide
impl PassportElementErrorReverseSide
pub fn new(source: String, file_hash: String, message: String) -> Self
sourcepub fn into_tuple(self) -> (String, String, String, String)
pub fn into_tuple(self) -> (String, String, String, String)
Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (source, type, file_hash, message)
sourcepub fn get_source<'a>(&'a self) -> Cow<'a, str>
pub fn get_source<'a>(&'a self) -> Cow<'a, str>
Error source, must be reverse_side
sourcepub fn get_source_ref<'a>(&'a self) -> &'a str
pub fn get_source_ref<'a>(&'a self) -> &'a str
Error source, must be reverse_side
sourcepub fn set_source<'a>(&'a mut self, source: String) -> &'a mut Self
pub fn set_source<'a>(&'a mut self, source: String) -> &'a mut Self
Error source, must be reverse_side
sourcepub fn get_tg_type<'a>(&'a self) -> Cow<'a, str>
pub fn get_tg_type<'a>(&'a self) -> Cow<'a, str>
The section of the user’s Telegram Passport which has the issue, one of “driver_license”, “identity_card”
sourcepub fn get_tg_type_ref<'a>(&'a self) -> &'a str
pub fn get_tg_type_ref<'a>(&'a self) -> &'a str
The section of the user’s Telegram Passport which has the issue, one of “driver_license”, “identity_card”
sourcepub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
pub fn set_tg_type<'a>(&'a mut self, tg_type: String) -> &'a mut Self
The section of the user’s Telegram Passport which has the issue, one of “driver_license”, “identity_card”
sourcepub fn get_file_hash<'a>(&'a self) -> Cow<'a, str>
pub fn get_file_hash<'a>(&'a self) -> Cow<'a, str>
Base64-encoded hash of the file with the reverse side of the document
sourcepub fn get_file_hash_ref<'a>(&'a self) -> &'a str
pub fn get_file_hash_ref<'a>(&'a self) -> &'a str
Base64-encoded hash of the file with the reverse side of the document
sourcepub fn set_file_hash<'a>(&'a mut self, file_hash: String) -> &'a mut Self
pub fn set_file_hash<'a>(&'a mut self, file_hash: String) -> &'a mut Self
Base64-encoded hash of the file with the reverse side of the document
sourcepub fn get_message<'a>(&'a self) -> Cow<'a, str>
pub fn get_message<'a>(&'a self) -> Cow<'a, str>
Error message
sourcepub fn get_message_ref<'a>(&'a self) -> &'a str
pub fn get_message_ref<'a>(&'a self) -> &'a str
Error message
sourcepub fn set_message<'a>(&'a mut self, message: String) -> &'a mut Self
pub fn set_message<'a>(&'a mut self, message: String) -> &'a mut Self
Error message