pub struct PassportElementErrorTranslationFileBuilder { /* private fields */ }Expand description
Represents an issue with one of the files that constitute the translation of a document. The error is considered resolved when the file changes.
Implementations
sourceimpl PassportElementErrorTranslationFileBuilder
impl PassportElementErrorTranslationFileBuilder
pub fn new(source: String, file_hash: String, message: String) -> Self
sourcepub fn set_source(self, source: String) -> Self
pub fn set_source(self, source: String) -> Self
Error source, must be translation_file
sourcepub fn set_type(self, tg_type: String) -> Self
pub fn set_type(self, tg_type: String) -> Self
Type of element of the user’s Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
sourcepub fn set_file_hash(self, file_hash: String) -> Self
pub fn set_file_hash(self, file_hash: String) -> Self
Base64-encoded file hash
sourcepub fn set_message(self, message: String) -> Self
pub fn set_message(self, message: String) -> Self
Error message
pub fn build(self) -> PassportElementErrorTranslationFile