PhotoSizeBuilder

Struct PhotoSizeBuilder 

pub struct PhotoSizeBuilder {
    pub file_id: String,
    pub file_unique_id: String,
    pub width: i64,
    pub height: i64,
    pub file_size: Option<i64>,
}
This object represents one size of a photo or a file / sticker thumbnail.

Fields

file_id: String

Identifier for this file, which can be used to download or reuse the file

file_unique_id: String

Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.

width: i64

Photo width

height: i64

Photo height

file_size: Option<i64>

Optional. File size in bytes

Implementations

Source

impl PhotoSizeBuilder

pub fn new( file_id: String, file_unique_id: String, width: i64, height: i64, ) -> Self

pub fn set_file_id(self, file_id: String) -> Self

Identifier for this file, which can be used to download or reuse the file

pub fn set_file_unique_id(self, file_unique_id: String) -> Self

Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.

pub fn set_width(self, width: i64) -> Self

Photo width

pub fn set_height(self, height: i64) -> Self

Photo height

pub fn set_file_size(self, file_size: i64) -> Self

Optional. File size in bytes

pub fn build(self) -> PhotoSize