pub struct ReplyKeyboardRemove { /* private fields */ }
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).

Implementations

source

impl ReplyKeyboardRemove

source

impl ReplyKeyboardRemove

source

pub fn new(remove_keyboard: bool) -> Self

source

pub fn into_tuple(self) -> (bool, Option<bool>)

Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (remove_keyboard, selective)

source

pub fn get_remove_keyboard<'a>(&'a self) -> bool

Requests clients to remove the custom keyboard (user will not be able to summon this keyboard; if you want to hide the keyboard from sight but keep it accessible, use one_time_keyboard in ReplyKeyboardMarkup)

source

pub fn get_remove_keyboard_ref<'a>(&'a self) -> bool

Requests clients to remove the custom keyboard (user will not be able to summon this keyboard; if you want to hide the keyboard from sight but keep it accessible, use one_time_keyboard in ReplyKeyboardMarkup)

source

pub fn set_remove_keyboard<'a>( &'a mut self, remove_keyboard: bool ) -> &'a mut Self

Requests clients to remove the custom keyboard (user will not be able to summon this keyboard; if you want to hide the keyboard from sight but keep it accessible, use one_time_keyboard in ReplyKeyboardMarkup)

source

pub fn get_selective<'a>(&'a self) -> Option<bool>

Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply (has reply_to_message_id), sender of the original message. Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven’t voted yet.

source

pub fn get_selective_ref<'a>(&'a self) -> Option<bool>

Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply (has reply_to_message_id), sender of the original message. Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven’t voted yet.

source

pub fn set_selective<'a>(&'a mut self, selective: Option<bool>) -> &'a mut Self

Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot’s message is a reply (has reply_to_message_id), sender of the original message. Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven’t voted yet.