StarTransactionBuilder

Struct StarTransactionBuilder 

pub struct StarTransactionBuilder {
    pub id: String,
    pub amount: i64,
    pub nanostar_amount: Option<i64>,
    pub date: i64,
    pub source: Option<BoxWrapper<Unbox<TransactionPartner>>>,
    pub receiver: Option<BoxWrapper<Unbox<TransactionPartner>>>,
}
Describes a Telegram Star transaction. Note that if the buyer initiates a chargeback with the payment provider from whom they acquired Stars (e.g., Apple, Google) following this transaction, the refunded Stars will be deducted from the bot’s balance. This is outside of Telegram’s control.

Fields

id: String

Unique identifier of the transaction. Coincides with the identifier of the original transaction for refund transactions. Coincides with SuccessfulPayment.telegram_payment_charge_id for successful incoming payments from users.

amount: i64

Integer amount of Telegram Stars transferred by the transaction

nanostar_amount: Option<i64>

Optional. The number of 1/1000000000 shares of Telegram Stars transferred by the transaction; from 0 to 999999999

date: i64

Date the transaction was created in Unix time

source: Option<BoxWrapper<Unbox<TransactionPartner>>>

Optional. Source of an incoming transaction (e.g., a user purchasing goods or services, Fragment refunding a failed withdrawal). Only for incoming transactions

receiver: Option<BoxWrapper<Unbox<TransactionPartner>>>

Optional. Receiver of an outgoing transaction (e.g., a user for a purchase refund, Fragment for a withdrawal). Only for outgoing transactions

Implementations

Source

impl StarTransactionBuilder

pub fn new(id: String, amount: i64, date: i64) -> Self

pub fn set_id(self, id: String) -> Self

Unique identifier of the transaction. Coincides with the identifier of the original transaction for refund transactions. Coincides with SuccessfulPayment.telegram_payment_charge_id for successful incoming payments from users.

pub fn set_amount(self, amount: i64) -> Self

Integer amount of Telegram Stars transferred by the transaction

pub fn set_nanostar_amount(self, nanostar_amount: i64) -> Self

Optional. The number of 1/1000000000 shares of Telegram Stars transferred by the transaction; from 0 to 999999999

pub fn set_date(self, date: i64) -> Self

Date the transaction was created in Unix time

pub fn set_source(self, source: TransactionPartner) -> Self

Optional. Source of an incoming transaction (e.g., a user purchasing goods or services, Fragment refunding a failed withdrawal). Only for incoming transactions

pub fn set_receiver(self, receiver: TransactionPartner) -> Self

Optional. Receiver of an outgoing transaction (e.g., a user for a purchase refund, Fragment for a withdrawal). Only for outgoing transactions

pub fn build(self) -> StarTransaction