StickerBuilder

Struct StickerBuilder 

pub struct StickerBuilder {
Show 15 fields pub file_id: String, pub file_unique_id: String, pub tg_type: String, pub width: i64, pub height: i64, pub is_animated: bool, pub is_video: bool, pub thumbnail: Option<BoxWrapper<Unbox<PhotoSize>>>, pub emoji: Option<String>, pub set_name: Option<String>, pub premium_animation: Option<BoxWrapper<Unbox<File>>>, pub mask_position: Option<BoxWrapper<Unbox<MaskPosition>>>, pub custom_emoji_id: Option<String>, pub needs_repainting: Option<bool>, pub file_size: Option<i64>,
}
This object represents a sticker.

Fields

file_id: String

Identifier for this file, which can be used to download or reuse the file

file_unique_id: String

Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.

tg_type: String

Type of the sticker, currently one of “regular”, “mask”, “custom_emoji”. The type of the sticker is independent from its format, which is determined by the fields is_animated and is_video.

width: i64

Sticker width

height: i64

Sticker height

is_animated: bool

True, if the sticker is animated

is_video: bool

True, if the sticker is a video sticker

thumbnail: Option<BoxWrapper<Unbox<PhotoSize>>>

Optional. Sticker thumbnail in the .WEBP or .JPG format

emoji: Option<String>

Optional. Emoji associated with the sticker

set_name: Option<String>

Optional. Name of the sticker set to which the sticker belongs

premium_animation: Option<BoxWrapper<Unbox<File>>>

Optional. For premium regular stickers, premium animation for the sticker

mask_position: Option<BoxWrapper<Unbox<MaskPosition>>>

Optional. For mask stickers, the position where the mask should be placed

custom_emoji_id: Option<String>

Optional. For custom emoji stickers, unique identifier of the custom emoji

needs_repainting: Option<bool>

Optional. True, if the sticker must be repainted to a text color in messages, the color of the Telegram Premium badge in emoji status, white color on chat photos, or another appropriate color in other places

file_size: Option<i64>

Optional. File size in bytes

Implementations

Source

impl StickerBuilder

pub fn new( file_id: String, file_unique_id: String, width: i64, height: i64, is_animated: bool, is_video: bool, ) -> Self

pub fn set_file_id(self, file_id: String) -> Self

Identifier for this file, which can be used to download or reuse the file

pub fn set_file_unique_id(self, file_unique_id: String) -> Self

Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.

pub fn set_type(self, tg_type: String) -> Self

Type of the sticker, currently one of “regular”, “mask”, “custom_emoji”. The type of the sticker is independent from its format, which is determined by the fields is_animated and is_video.

pub fn set_width(self, width: i64) -> Self

Sticker width

pub fn set_height(self, height: i64) -> Self

Sticker height

pub fn set_is_animated(self, is_animated: bool) -> Self

True, if the sticker is animated

pub fn set_is_video(self, is_video: bool) -> Self

True, if the sticker is a video sticker

pub fn set_thumbnail(self, thumbnail: PhotoSize) -> Self

Optional. Sticker thumbnail in the .WEBP or .JPG format

pub fn set_emoji(self, emoji: String) -> Self

Optional. Emoji associated with the sticker

pub fn set_set_name(self, set_name: String) -> Self

Optional. Name of the sticker set to which the sticker belongs

pub fn set_premium_animation(self, premium_animation: File) -> Self

Optional. For premium regular stickers, premium animation for the sticker

pub fn set_mask_position(self, mask_position: MaskPosition) -> Self

Optional. For mask stickers, the position where the mask should be placed

pub fn set_custom_emoji_id(self, custom_emoji_id: String) -> Self

Optional. For custom emoji stickers, unique identifier of the custom emoji

pub fn set_needs_repainting(self, needs_repainting: bool) -> Self

Optional. True, if the sticker must be repainted to a text color in messages, the color of the Telegram Premium badge in emoji status, white color on chat photos, or another appropriate color in other places

pub fn set_file_size(self, file_size: i64) -> Self

Optional. File size in bytes

pub fn build(self) -> Sticker