StoryAreaPositionBuilder

Struct StoryAreaPositionBuilder 

pub struct StoryAreaPositionBuilder {
    pub x_percentage: OrderedFloat<f64>,
    pub y_percentage: OrderedFloat<f64>,
    pub width_percentage: OrderedFloat<f64>,
    pub height_percentage: OrderedFloat<f64>,
    pub rotation_angle: OrderedFloat<f64>,
    pub corner_radius_percentage: OrderedFloat<f64>,
}
Describes the position of a clickable area within a story.

Fields

x_percentage: OrderedFloat<f64>

The abscissa of the area’s center, as a percentage of the media width

y_percentage: OrderedFloat<f64>

The ordinate of the area’s center, as a percentage of the media height

width_percentage: OrderedFloat<f64>

The width of the area’s rectangle, as a percentage of the media width

height_percentage: OrderedFloat<f64>

The height of the area’s rectangle, as a percentage of the media height

rotation_angle: OrderedFloat<f64>

The clockwise rotation angle of the rectangle, in degrees; 0-360

corner_radius_percentage: OrderedFloat<f64>

The radius of the rectangle corner rounding, as a percentage of the media width

Implementations

Source

impl StoryAreaPositionBuilder

pub fn new( x_percentage: OrderedFloat<f64>, y_percentage: OrderedFloat<f64>, width_percentage: OrderedFloat<f64>, height_percentage: OrderedFloat<f64>, rotation_angle: OrderedFloat<f64>, corner_radius_percentage: OrderedFloat<f64>, ) -> Self

pub fn set_x_percentage(self, x_percentage: OrderedFloat<f64>) -> Self

The abscissa of the area’s center, as a percentage of the media width

pub fn set_y_percentage(self, y_percentage: OrderedFloat<f64>) -> Self

The ordinate of the area’s center, as a percentage of the media height

pub fn set_width_percentage(self, width_percentage: OrderedFloat<f64>) -> Self

The width of the area’s rectangle, as a percentage of the media width

pub fn set_height_percentage(self, height_percentage: OrderedFloat<f64>) -> Self

The height of the area’s rectangle, as a percentage of the media height

pub fn set_rotation_angle(self, rotation_angle: OrderedFloat<f64>) -> Self

The clockwise rotation angle of the rectangle, in degrees; 0-360

pub fn set_corner_radius_percentage( self, corner_radius_percentage: OrderedFloat<f64>, ) -> Self

The radius of the rectangle corner rounding, as a percentage of the media width

pub fn build(self) -> StoryAreaPosition