pub struct SuggestedPostApprovalFailed {
pub suggested_post_message: Option<BoxWrapper<Box<Message>>>,
pub price: BoxWrapper<Unbox<SuggestedPostPrice>>,
}Expand description
Describes a service message about the failed approval of a suggested post. Currently, only caused by insufficient user funds at the time of approval.
Fields
suggested_post_message: Option<BoxWrapper<Box<Message>>>Optional. Message containing the suggested post whose approval has failed. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
price: BoxWrapper<Unbox<SuggestedPostPrice>>Expected price of the post
Implementations
Sourceimpl SuggestedPostApprovalFailed
impl SuggestedPostApprovalFailed
pub fn noskip(self) -> NoSkipSuggestedPostApprovalFailed
Sourceimpl SuggestedPostApprovalFailed
impl SuggestedPostApprovalFailed
pub fn new<A: Into<SuggestedPostPrice>>(price: A) -> Self
Sourcepub fn get_suggested_post_message<'a>(&'a self) -> Option<&'a Message>
pub fn get_suggested_post_message<'a>(&'a self) -> Option<&'a Message>
Optional. Message containing the suggested post whose approval has failed. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Sourcepub fn set_suggested_post_message<'a>(
&'a mut self,
suggested_post_message: Option<Message>,
) -> &'a mut Self
pub fn set_suggested_post_message<'a>( &'a mut self, suggested_post_message: Option<Message>, ) -> &'a mut Self
Optional. Message containing the suggested post whose approval has failed. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Sourcepub fn get_price<'a>(&'a self) -> &'a SuggestedPostPrice
pub fn get_price<'a>(&'a self) -> &'a SuggestedPostPrice
Expected price of the post
Sourcepub fn set_price<'a>(&'a mut self, price: SuggestedPostPrice) -> &'a mut Self
pub fn set_price<'a>(&'a mut self, price: SuggestedPostPrice) -> &'a mut Self
Expected price of the post