pub struct SuggestedPostApprovedBuilder {
pub suggested_post_message: Option<BoxWrapper<Box<Message>>>,
pub price: Option<BoxWrapper<Unbox<SuggestedPostPrice>>>,
pub send_date: i64,
}Expand description
Describes a service message about the approval of a suggested post.
Fields
suggested_post_message: Option<BoxWrapper<Box<Message>>>Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
price: Option<BoxWrapper<Unbox<SuggestedPostPrice>>>Optional. Amount paid for the post
send_date: i64Date when the post will be published
Implementations
Sourceimpl SuggestedPostApprovedBuilder
impl SuggestedPostApprovedBuilder
pub fn new(send_date: i64) -> Self
Sourcepub fn set_suggested_post_message(
self,
suggested_post_message: Box<Message>,
) -> Self
pub fn set_suggested_post_message( self, suggested_post_message: Box<Message>, ) -> Self
Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Sourcepub fn set_price(self, price: SuggestedPostPrice) -> Self
pub fn set_price(self, price: SuggestedPostPrice) -> Self
Optional. Amount paid for the post
Sourcepub fn set_send_date(self, send_date: i64) -> Self
pub fn set_send_date(self, send_date: i64) -> Self
Date when the post will be published
pub fn build(self) -> SuggestedPostApproved