pub struct SuggestedPostParametersBuilder {
pub price: Option<BoxWrapper<Unbox<SuggestedPostPrice>>>,
pub send_date: Option<i64>,
}Expand description
Contains parameters of a post that is being suggested by the bot.
Fields
price: Option<BoxWrapper<Unbox<SuggestedPostPrice>>>Optional. Proposed price for the post. If the field is omitted, then the post is unpaid.
send_date: Option<i64>Optional. Proposed send date of the post. If specified, then the date must be between 300 second and 2678400 seconds (30 days) in the future. If the field is omitted, then the post can be published at any time within 30 days at the sole discretion of the user who approves it.
Implementations
Sourceimpl SuggestedPostParametersBuilder
impl SuggestedPostParametersBuilder
pub fn new() -> Self
Sourcepub fn set_price(self, price: SuggestedPostPrice) -> Self
pub fn set_price(self, price: SuggestedPostPrice) -> Self
Optional. Proposed price for the post. If the field is omitted, then the post is unpaid.
Sourcepub fn set_send_date(self, send_date: i64) -> Self
pub fn set_send_date(self, send_date: i64) -> Self
Optional. Proposed send date of the post. If specified, then the date must be between 300 second and 2678400 seconds (30 days) in the future. If the field is omitted, then the post can be published at any time within 30 days at the sole discretion of the user who approves it.
pub fn build(self) -> SuggestedPostParameters