Struct botapi::gen_types::SwitchInlineQueryChosenChat
source · pub struct SwitchInlineQueryChosenChat { /* private fields */ }Expand description
This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.
Implementations
sourceimpl SwitchInlineQueryChosenChat
impl SwitchInlineQueryChosenChat
pub fn noskip(self) -> NoSkipSwitchInlineQueryChosenChat
sourceimpl SwitchInlineQueryChosenChat
impl SwitchInlineQueryChosenChat
pub fn new() -> Self
sourcepub fn into_tuple(
self
) -> (Option<String>, Option<bool>, Option<bool>, Option<bool>, Option<bool>)
pub fn into_tuple( self ) -> (Option<String>, Option<bool>, Option<bool>, Option<bool>, Option<bool>)
Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (query, allow_user_chats, allow_bot_chats, allow_group_chats, allow_channel_chats)
sourcepub fn get_query<'a>(&'a self) -> Option<Cow<'a, str>>
pub fn get_query<'a>(&'a self) -> Option<Cow<'a, str>>
Optional. The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted
sourcepub fn get_query_ref<'a>(&'a self) -> Option<&'a str>
pub fn get_query_ref<'a>(&'a self) -> Option<&'a str>
Optional. The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted
sourcepub fn set_query<'a>(&'a mut self, query: Option<String>) -> &'a mut Self
pub fn set_query<'a>(&'a mut self, query: Option<String>) -> &'a mut Self
Optional. The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted
sourcepub fn get_allow_user_chats<'a>(&'a self) -> Option<bool>
pub fn get_allow_user_chats<'a>(&'a self) -> Option<bool>
Optional. True, if private chats with users can be chosen
sourcepub fn get_allow_user_chats_ref<'a>(&'a self) -> Option<bool>
pub fn get_allow_user_chats_ref<'a>(&'a self) -> Option<bool>
Optional. True, if private chats with users can be chosen
sourcepub fn set_allow_user_chats<'a>(
&'a mut self,
allow_user_chats: Option<bool>
) -> &'a mut Self
pub fn set_allow_user_chats<'a>( &'a mut self, allow_user_chats: Option<bool> ) -> &'a mut Self
Optional. True, if private chats with users can be chosen
sourcepub fn get_allow_bot_chats<'a>(&'a self) -> Option<bool>
pub fn get_allow_bot_chats<'a>(&'a self) -> Option<bool>
Optional. True, if private chats with bots can be chosen
sourcepub fn get_allow_bot_chats_ref<'a>(&'a self) -> Option<bool>
pub fn get_allow_bot_chats_ref<'a>(&'a self) -> Option<bool>
Optional. True, if private chats with bots can be chosen
sourcepub fn set_allow_bot_chats<'a>(
&'a mut self,
allow_bot_chats: Option<bool>
) -> &'a mut Self
pub fn set_allow_bot_chats<'a>( &'a mut self, allow_bot_chats: Option<bool> ) -> &'a mut Self
Optional. True, if private chats with bots can be chosen
sourcepub fn get_allow_group_chats<'a>(&'a self) -> Option<bool>
pub fn get_allow_group_chats<'a>(&'a self) -> Option<bool>
Optional. True, if group and supergroup chats can be chosen
sourcepub fn get_allow_group_chats_ref<'a>(&'a self) -> Option<bool>
pub fn get_allow_group_chats_ref<'a>(&'a self) -> Option<bool>
Optional. True, if group and supergroup chats can be chosen
sourcepub fn set_allow_group_chats<'a>(
&'a mut self,
allow_group_chats: Option<bool>
) -> &'a mut Self
pub fn set_allow_group_chats<'a>( &'a mut self, allow_group_chats: Option<bool> ) -> &'a mut Self
Optional. True, if group and supergroup chats can be chosen
sourcepub fn get_allow_channel_chats<'a>(&'a self) -> Option<bool>
pub fn get_allow_channel_chats<'a>(&'a self) -> Option<bool>
Optional. True, if channel chats can be chosen
sourcepub fn get_allow_channel_chats_ref<'a>(&'a self) -> Option<bool>
pub fn get_allow_channel_chats_ref<'a>(&'a self) -> Option<bool>
Optional. True, if channel chats can be chosen
sourcepub fn set_allow_channel_chats<'a>(
&'a mut self,
allow_channel_chats: Option<bool>
) -> &'a mut Self
pub fn set_allow_channel_chats<'a>( &'a mut self, allow_channel_chats: Option<bool> ) -> &'a mut Self
Optional. True, if channel chats can be chosen