pub struct SwitchInlineQueryChosenChatBuilder { /* private fields */ }Expand description
This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.
Implementations
sourceimpl SwitchInlineQueryChosenChatBuilder
impl SwitchInlineQueryChosenChatBuilder
pub fn new() -> Self
sourcepub fn set_query(self, query: String) -> Self
pub fn set_query(self, query: String) -> Self
Optional. The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted
sourcepub fn set_allow_user_chats(self, allow_user_chats: bool) -> Self
pub fn set_allow_user_chats(self, allow_user_chats: bool) -> Self
Optional. True, if private chats with users can be chosen
sourcepub fn set_allow_bot_chats(self, allow_bot_chats: bool) -> Self
pub fn set_allow_bot_chats(self, allow_bot_chats: bool) -> Self
Optional. True, if private chats with bots can be chosen
sourcepub fn set_allow_group_chats(self, allow_group_chats: bool) -> Self
pub fn set_allow_group_chats(self, allow_group_chats: bool) -> Self
Optional. True, if group and supergroup chats can be chosen
sourcepub fn set_allow_channel_chats(self, allow_channel_chats: bool) -> Self
pub fn set_allow_channel_chats(self, allow_channel_chats: bool) -> Self
Optional. True, if channel chats can be chosen
pub fn build(self) -> SwitchInlineQueryChosenChat