pub struct TransactionPartnerAffiliateProgramBuilder {
pub tg_type: String,
pub sponsor_user: Option<BoxWrapper<Unbox<User>>>,
pub commission_per_mille: i64,
}Expand description
Describes the affiliate program that issued the affiliate commission received via this transaction.
Fields
tg_type: StringType of the transaction partner, always “affiliate_program”
sponsor_user: Option<BoxWrapper<Unbox<User>>>Optional. Information about the bot that sponsored the affiliate program
commission_per_mille: i64The number of Telegram Stars received by the bot for each 1000 Telegram Stars received by the affiliate program sponsor from referred users
Implementations
Sourceimpl TransactionPartnerAffiliateProgramBuilder
impl TransactionPartnerAffiliateProgramBuilder
pub fn new(commission_per_mille: i64) -> Self
Sourcepub fn set_type(self, tg_type: String) -> Self
pub fn set_type(self, tg_type: String) -> Self
Type of the transaction partner, always “affiliate_program”
Sourcepub fn set_sponsor_user(self, sponsor_user: User) -> Self
pub fn set_sponsor_user(self, sponsor_user: User) -> Self
Optional. Information about the bot that sponsored the affiliate program
Sourcepub fn set_commission_per_mille(self, commission_per_mille: i64) -> Self
pub fn set_commission_per_mille(self, commission_per_mille: i64) -> Self
The number of Telegram Stars received by the bot for each 1000 Telegram Stars received by the affiliate program sponsor from referred users
pub fn build(self) -> TransactionPartnerAffiliateProgram