pub struct TransactionPartnerTelegramApiBuilder {
pub tg_type: String,
pub request_count: i64,
}Expand description
Describes a transaction with payment for paid broadcasting.
Fields
tg_type: StringType of the transaction partner, always “telegram_api”
request_count: i64The number of successful requests that exceeded regular limits and were therefore billed
Implementations
Sourceimpl TransactionPartnerTelegramApiBuilder
impl TransactionPartnerTelegramApiBuilder
pub fn new(request_count: i64) -> Self
Sourcepub fn set_type(self, tg_type: String) -> Self
pub fn set_type(self, tg_type: String) -> Self
Type of the transaction partner, always “telegram_api”
Sourcepub fn set_request_count(self, request_count: i64) -> Self
pub fn set_request_count(self, request_count: i64) -> Self
The number of successful requests that exceeded regular limits and were therefore billed
pub fn build(self) -> TransactionPartnerTelegramApi