Struct botapi::gen_types::WebAppDataBuilder
source · pub struct WebAppDataBuilder { /* private fields */ }Expand description
Describes data sent from a Web App to the bot.
Implementations
sourceimpl WebAppDataBuilder
impl WebAppDataBuilder
pub fn new(data: String, button_text: String) -> Self
sourcepub fn set_data(self, data: String) -> Self
pub fn set_data(self, data: String) -> Self
The data. Be aware that a bad client can send arbitrary data in this field.
Text of the web_app keyboard button from which the Web App was opened. Be aware that a bad client can send arbitrary data in this field.
pub fn build(self) -> WebAppData