Struct botapi::gen_types::WebAppInfo
source · pub struct WebAppInfo { /* private fields */ }Expand description
Describes a Web App.
Implementations
sourceimpl WebAppInfo
impl WebAppInfo
pub fn noskip(self) -> NoSkipWebAppInfo
sourceimpl WebAppInfo
impl WebAppInfo
pub fn new(url: String) -> Self
sourcepub fn into_tuple(self) -> String
pub fn into_tuple(self) -> String
Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (url)
sourcepub fn get_url<'a>(&'a self) -> Cow<'a, str>
pub fn get_url<'a>(&'a self) -> Cow<'a, str>
An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps
sourcepub fn get_url_ref<'a>(&'a self) -> &'a str
pub fn get_url_ref<'a>(&'a self) -> &'a str
An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps
sourcepub fn set_url<'a>(&'a mut self, url: String) -> &'a mut Self
pub fn set_url<'a>(&'a mut self, url: String) -> &'a mut Self
An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps