pub struct WriteAccessAllowed { /* private fields */ }
This object represents a service message about a user allowing a bot to write messages after adding it to the attachment menu, launching a Web App from a link, or accepting an explicit request from a Web App sent by the method requestWriteAccess.

Implementations

source

impl WriteAccessAllowed

source

impl WriteAccessAllowed

source

pub fn new() -> Self

source

pub fn into_tuple(self) -> (Option<bool>, Option<String>, Option<bool>)

Consumes and deconstructs this type into a tuple with one element per field. Tuple type returned is: (from_request, web_app_name, from_attachment_menu)

source

pub fn get_from_request<'a>(&'a self) -> Option<bool>

Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess

source

pub fn get_from_request_ref<'a>(&'a self) -> Option<bool>

Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess

source

pub fn set_from_request<'a>( &'a mut self, from_request: Option<bool> ) -> &'a mut Self

Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess

source

pub fn get_web_app_name<'a>(&'a self) -> Option<Cow<'a, str>>

Optional. Name of the Web App, if the access was granted when the Web App was launched from a link

source

pub fn get_web_app_name_ref<'a>(&'a self) -> Option<&'a str>

Optional. Name of the Web App, if the access was granted when the Web App was launched from a link

source

pub fn set_web_app_name<'a>( &'a mut self, web_app_name: Option<String> ) -> &'a mut Self

Optional. Name of the Web App, if the access was granted when the Web App was launched from a link

source

pub fn get_from_attachment_menu<'a>(&'a self) -> Option<bool>

Optional. True, if the access was granted when the bot was added to the attachment or side menu

source

pub fn get_from_attachment_menu_ref<'a>(&'a self) -> Option<bool>

Optional. True, if the access was granted when the bot was added to the attachment or side menu

source

pub fn set_from_attachment_menu<'a>( &'a mut self, from_attachment_menu: Option<bool> ) -> &'a mut Self

Optional. True, if the access was granted when the bot was added to the attachment or side menu