pub struct WriteAccessAllowedBuilder {
pub from_request: Option<bool>,
pub web_app_name: Option<String>,
pub from_attachment_menu: Option<bool>,
}Expand description
This object represents a service message about a user allowing a bot to write messages after adding it to the attachment menu, launching a Web App from a link, or accepting an explicit request from a Web App sent by the method requestWriteAccess.
Fields
from_request: Option<bool>Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess
web_app_name: Option<String>Optional. Name of the Web App, if the access was granted when the Web App was launched from a link
Optional. True, if the access was granted when the bot was added to the attachment or side menu
Implementations
Sourceimpl WriteAccessAllowedBuilder
impl WriteAccessAllowedBuilder
pub fn new() -> Self
Sourcepub fn set_from_request(self, from_request: bool) -> Self
pub fn set_from_request(self, from_request: bool) -> Self
Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess
Sourcepub fn set_web_app_name(self, web_app_name: String) -> Self
pub fn set_web_app_name(self, web_app_name: String) -> Self
Optional. Name of the Web App, if the access was granted when the Web App was launched from a link
Optional. True, if the access was granted when the bot was added to the attachment or side menu
pub fn build(self) -> WriteAccessAllowed