pub struct CallCreateNewStickerSet<'a> { /* private fields */ }

Implementations

source

impl<'a> CallCreateNewStickerSet<'a>

source

pub fn user_id(self, user_id: i64) -> Self

User identifier of created sticker set owner

source

pub fn name(self, name: &'a str) -> Self

Short name of sticker set, to be used in t.me/addstickers/ URLs (e.g., animals). Can contain only English letters, digits and underscores. Must begin with a letter, can’t contain consecutive underscores and must end in “by<bot_username>”. <bot_username> is case insensitive. 1-64 characters.

source

pub fn title(self, title: &'a str) -> Self

Sticker set title, 1-64 characters

source

pub fn png_sticker(self, png_sticker: FileData) -> Self

PNG image with the sticker, must be up to 512 kilobytes in size, dimensions must not exceed 512px, and either width or height must be exactly 512px. Pass a file_id as a String to send a file that already exists on the Telegram servers, pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one using multipart/form-data. More information on Sending Files: https://core.telegram.org/bots/api#sending-files

source

pub fn tgs_sticker(self, tgs_sticker: FileData) -> Self

TGS animation with the sticker, uploaded using multipart/form-data. See https://core.telegram.org/stickers#animated-sticker-requirements for technical requirements

source

pub fn webm_sticker(self, webm_sticker: FileData) -> Self

WEBM video with the sticker, uploaded using multipart/form-data. See https://core.telegram.org/stickers#video-sticker-requirements for technical requirements

source

pub fn sticker_type(self, sticker_type: &'a str) -> Self

Type of stickers in the set, pass “regular” or “mask”. Custom emoji sticker sets can’t be created via the Bot API at the moment. By default, a regular sticker set is created.

source

pub fn emojis(self, emojis: &'a str) -> Self

One or more emoji corresponding to the sticker

source

pub fn mask_position(self, mask_position: &'a MaskPosition) -> Self

A JSON-serialized object for position where the mask should be placed on faces

source

pub async fn build(self) -> BotResult<bool>