pub struct CallEditForumTopic<'a, V> { /* private fields */ }Implementations
Sourceimpl<'a, V: Into<ChatHandle> + Serialize> CallEditForumTopic<'a, V>
impl<'a, V: Into<ChatHandle> + Serialize> CallEditForumTopic<'a, V>
Sourcepub fn chat_id(self, chat_id: V) -> Self
pub fn chat_id(self, chat_id: V) -> Self
Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
pub fn get_chat_id(&'a self) -> &'a V
Sourcepub fn message_thread_id(self, message_thread_id: i64) -> Self
pub fn message_thread_id(self, message_thread_id: i64) -> Self
Unique identifier for the target message thread of the forum topic
pub fn get_message_thread_id(&'a self) -> &'a i64
Sourcepub fn name(self, name: &'a str) -> Self
pub fn name(self, name: &'a str) -> Self
New topic name, 0-128 characters. If not specified or empty, the current name of the topic will be kept
pub fn get_name(&'a self) -> &'a Option<&'a str>
Sourcepub fn icon_custom_emoji_id(self, icon_custom_emoji_id: &'a str) -> Self
pub fn icon_custom_emoji_id(self, icon_custom_emoji_id: &'a str) -> Self
New unique identifier of the custom emoji shown as the topic icon. Use getForumTopicIconStickers to get all allowed custom emoji identifiers. Pass an empty string to remove the icon. If not specified, the current icon will be kept
pub fn get_icon_custom_emoji_id(&'a self) -> &'a Option<&'a str>
pub async fn build(self) -> BotResult<bool>