pub struct CallForwardMessage<'a, V> { /* private fields */ }Implementations
Sourceimpl<'a, V: Into<ChatHandle> + Serialize> CallForwardMessage<'a, V>
impl<'a, V: Into<ChatHandle> + Serialize> CallForwardMessage<'a, V>
Sourcepub fn chat_id(self, chat_id: V) -> Self
pub fn chat_id(self, chat_id: V) -> Self
Unique identifier for the target chat or username of the target channel (in the format @channelusername)
pub fn get_chat_id(&'a self) -> &'a V
Sourcepub fn message_thread_id(self, message_thread_id: i64) -> Self
pub fn message_thread_id(self, message_thread_id: i64) -> Self
Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only
pub fn get_message_thread_id(&'a self) -> &'a Option<i64>
Sourcepub fn direct_messages_topic_id(self, direct_messages_topic_id: i64) -> Self
pub fn direct_messages_topic_id(self, direct_messages_topic_id: i64) -> Self
Identifier of the direct messages topic to which the message will be forwarded; required if the message is forwarded to a direct messages chat
pub fn get_direct_messages_topic_id(&'a self) -> &'a Option<i64>
Sourcepub fn from_chat_id(self, from_chat_id: V) -> Self
pub fn from_chat_id(self, from_chat_id: V) -> Self
Unique identifier for the chat where the original message was sent (or channel username in the format @channelusername)
pub fn get_from_chat_id(&'a self) -> &'a V
Sourcepub fn video_start_timestamp(self, video_start_timestamp: i64) -> Self
pub fn video_start_timestamp(self, video_start_timestamp: i64) -> Self
New start timestamp for the forwarded video in the message
pub fn get_video_start_timestamp(&'a self) -> &'a Option<i64>
Sourcepub fn disable_notification(self, disable_notification: bool) -> Self
pub fn disable_notification(self, disable_notification: bool) -> Self
Sends the message silently. Users will receive a notification with no sound.
pub fn get_disable_notification(&'a self) -> &'a Option<bool>
Sourcepub fn protect_content(self, protect_content: bool) -> Self
pub fn protect_content(self, protect_content: bool) -> Self
Protects the contents of the forwarded message from forwarding and saving
pub fn get_protect_content(&'a self) -> &'a Option<bool>
Sourcepub fn message_effect_id(self, message_effect_id: &'a str) -> Self
pub fn message_effect_id(self, message_effect_id: &'a str) -> Self
Unique identifier of the message effect to be added to the message; only available when forwarding to private chats
pub fn get_message_effect_id(&'a self) -> &'a Option<&'a str>
Sourcepub fn suggested_post_parameters<T>(self, suggested_post_parameters: T) -> Selfwhere
T: Into<&'a SuggestedPostParameters>,
pub fn suggested_post_parameters<T>(self, suggested_post_parameters: T) -> Selfwhere
T: Into<&'a SuggestedPostParameters>,
A JSON-serialized object containing the parameters of the suggested post to send; for direct messages chats only
pub fn get_suggested_post_parameters( &'a self, ) -> &'a Option<&'a SuggestedPostParameters>
Sourcepub fn message_id(self, message_id: i64) -> Self
pub fn message_id(self, message_id: i64) -> Self
Message identifier in the chat specified in from_chat_id