pub struct CallGetUserGifts<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CallGetUserGifts<'a>
impl<'a> CallGetUserGifts<'a>
pub fn get_user_id(&'a self) -> &'a i64
Sourcepub fn exclude_unlimited(self, exclude_unlimited: bool) -> Self
pub fn exclude_unlimited(self, exclude_unlimited: bool) -> Self
Pass True to exclude gifts that can be purchased an unlimited number of times
pub fn get_exclude_unlimited(&'a self) -> &'a Option<bool>
Sourcepub fn exclude_limited_upgradable(
self,
exclude_limited_upgradable: bool,
) -> Self
pub fn exclude_limited_upgradable( self, exclude_limited_upgradable: bool, ) -> Self
Pass True to exclude gifts that can be purchased a limited number of times and can be upgraded to unique
pub fn get_exclude_limited_upgradable(&'a self) -> &'a Option<bool>
Sourcepub fn exclude_limited_non_upgradable(
self,
exclude_limited_non_upgradable: bool,
) -> Self
pub fn exclude_limited_non_upgradable( self, exclude_limited_non_upgradable: bool, ) -> Self
Pass True to exclude gifts that can be purchased a limited number of times and can’t be upgraded to unique
pub fn get_exclude_limited_non_upgradable(&'a self) -> &'a Option<bool>
Sourcepub fn exclude_from_blockchain(self, exclude_from_blockchain: bool) -> Self
pub fn exclude_from_blockchain(self, exclude_from_blockchain: bool) -> Self
Pass True to exclude gifts that were assigned from the TON blockchain and can’t be resold or transferred in Telegram
pub fn get_exclude_from_blockchain(&'a self) -> &'a Option<bool>
Sourcepub fn exclude_unique(self, exclude_unique: bool) -> Self
pub fn exclude_unique(self, exclude_unique: bool) -> Self
Pass True to exclude unique gifts
pub fn get_exclude_unique(&'a self) -> &'a Option<bool>
Sourcepub fn sort_by_price(self, sort_by_price: bool) -> Self
pub fn sort_by_price(self, sort_by_price: bool) -> Self
Pass True to sort results by gift price instead of send date. Sorting is applied before pagination.
pub fn get_sort_by_price(&'a self) -> &'a Option<bool>
Sourcepub fn offset(self, offset: &'a str) -> Self
pub fn offset(self, offset: &'a str) -> Self
Offset of the first entry to return as received from the previous request; use an empty string to get the first chunk of results
pub fn get_offset(&'a self) -> &'a Option<&'a str>
Sourcepub fn limit(self, limit: i64) -> Self
pub fn limit(self, limit: i64) -> Self
The maximum number of gifts to be returned; 1-100. Defaults to 100
pub fn get_limit(&'a self) -> &'a Option<i64>
pub async fn build(self) -> BotResult<OwnedGifts>