pub struct CallPromoteChatMember<'a, V> { /* private fields */ }Implementations
Sourceimpl<'a, V: Into<ChatHandle> + Serialize> CallPromoteChatMember<'a, V>
impl<'a, V: Into<ChatHandle> + Serialize> CallPromoteChatMember<'a, V>
Sourcepub fn chat_id(self, chat_id: V) -> Self
pub fn chat_id(self, chat_id: V) -> Self
Unique identifier for the target chat or username of the target channel (in the format @channelusername)
pub fn get_chat_id(&'a self) -> &'a V
pub fn get_user_id(&'a self) -> &'a i64
Sourcepub fn is_anonymous(self, is_anonymous: bool) -> Self
pub fn is_anonymous(self, is_anonymous: bool) -> Self
Pass True if the administrator’s presence in the chat is hidden
pub fn get_is_anonymous(&'a self) -> &'a Option<bool>
Sourcepub fn can_manage_chat(self, can_manage_chat: bool) -> Self
pub fn can_manage_chat(self, can_manage_chat: bool) -> Self
Pass True if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report spam messages, ignore slow mode, and send messages to the chat without paying Telegram Stars. Implied by any other administrator privilege.
pub fn get_can_manage_chat(&'a self) -> &'a Option<bool>
Sourcepub fn can_delete_messages(self, can_delete_messages: bool) -> Self
pub fn can_delete_messages(self, can_delete_messages: bool) -> Self
Pass True if the administrator can delete messages of other users
pub fn get_can_delete_messages(&'a self) -> &'a Option<bool>
Sourcepub fn can_manage_video_chats(self, can_manage_video_chats: bool) -> Self
pub fn can_manage_video_chats(self, can_manage_video_chats: bool) -> Self
Pass True if the administrator can manage video chats
pub fn get_can_manage_video_chats(&'a self) -> &'a Option<bool>
Sourcepub fn can_restrict_members(self, can_restrict_members: bool) -> Self
pub fn can_restrict_members(self, can_restrict_members: bool) -> Self
Pass True if the administrator can restrict, ban or unban chat members, or access supergroup statistics. For backward compatibility, defaults to True for promotions of channel administrators
pub fn get_can_restrict_members(&'a self) -> &'a Option<bool>
Sourcepub fn can_promote_members(self, can_promote_members: bool) -> Self
pub fn can_promote_members(self, can_promote_members: bool) -> Self
Pass True if the administrator can add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by him)
pub fn get_can_promote_members(&'a self) -> &'a Option<bool>
Sourcepub fn can_change_info(self, can_change_info: bool) -> Self
pub fn can_change_info(self, can_change_info: bool) -> Self
Pass True if the administrator can change chat title, photo and other settings
pub fn get_can_change_info(&'a self) -> &'a Option<bool>
Sourcepub fn can_invite_users(self, can_invite_users: bool) -> Self
pub fn can_invite_users(self, can_invite_users: bool) -> Self
Pass True if the administrator can invite new users to the chat
pub fn get_can_invite_users(&'a self) -> &'a Option<bool>
Sourcepub fn can_post_stories(self, can_post_stories: bool) -> Self
pub fn can_post_stories(self, can_post_stories: bool) -> Self
Pass True if the administrator can post stories to the chat
pub fn get_can_post_stories(&'a self) -> &'a Option<bool>
Sourcepub fn can_edit_stories(self, can_edit_stories: bool) -> Self
pub fn can_edit_stories(self, can_edit_stories: bool) -> Self
Pass True if the administrator can edit stories posted by other users, post stories to the chat page, pin chat stories, and access the chat’s story archive
pub fn get_can_edit_stories(&'a self) -> &'a Option<bool>
Sourcepub fn can_delete_stories(self, can_delete_stories: bool) -> Self
pub fn can_delete_stories(self, can_delete_stories: bool) -> Self
Pass True if the administrator can delete stories posted by other users
pub fn get_can_delete_stories(&'a self) -> &'a Option<bool>
Sourcepub fn can_post_messages(self, can_post_messages: bool) -> Self
pub fn can_post_messages(self, can_post_messages: bool) -> Self
Pass True if the administrator can post messages in the channel, approve suggested posts, or access channel statistics; for channels only
pub fn get_can_post_messages(&'a self) -> &'a Option<bool>
Sourcepub fn can_edit_messages(self, can_edit_messages: bool) -> Self
pub fn can_edit_messages(self, can_edit_messages: bool) -> Self
Pass True if the administrator can edit messages of other users and can pin messages; for channels only
pub fn get_can_edit_messages(&'a self) -> &'a Option<bool>
Sourcepub fn can_pin_messages(self, can_pin_messages: bool) -> Self
pub fn can_pin_messages(self, can_pin_messages: bool) -> Self
Pass True if the administrator can pin messages; for supergroups only
pub fn get_can_pin_messages(&'a self) -> &'a Option<bool>
Sourcepub fn can_manage_topics(self, can_manage_topics: bool) -> Self
pub fn can_manage_topics(self, can_manage_topics: bool) -> Self
Pass True if the user is allowed to create, rename, close, and reopen forum topics; for supergroups only
pub fn get_can_manage_topics(&'a self) -> &'a Option<bool>
Sourcepub fn can_manage_direct_messages(
self,
can_manage_direct_messages: bool,
) -> Self
pub fn can_manage_direct_messages( self, can_manage_direct_messages: bool, ) -> Self
Pass True if the administrator can manage direct messages within the channel and decline suggested posts; for channels only
pub fn get_can_manage_direct_messages(&'a self) -> &'a Option<bool>
Pass True if the administrator can edit the tags of regular members; for groups and supergroups only