Struct botapi::gen_methods::CallReopenForumTopic
source · pub struct CallReopenForumTopic<'a> { /* private fields */ }Implementations
sourceimpl<'a> CallReopenForumTopic<'a>
impl<'a> CallReopenForumTopic<'a>
sourcepub fn chat_id(self, chat_id: i64) -> Self
pub fn chat_id(self, chat_id: i64) -> Self
Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
pub fn get_chat_id(&'a self) -> &'a i64
sourcepub fn message_thread_id(self, message_thread_id: i64) -> Self
pub fn message_thread_id(self, message_thread_id: i64) -> Self
Unique identifier for the target message thread of the forum topic
pub fn get_message_thread_id(&'a self) -> &'a i64
pub async fn build(self) -> BotResult<bool>