Struct botapi::gen_types::CallbackQueryBuilder
source · pub struct CallbackQueryBuilder { /* private fields */ }Expand description
This object represents an incoming callback query from a callback button in an inline keyboard. If the button that originated the query was attached to a message sent by the bot, the field message will be present. If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present. Exactly one of the fields data or game_short_name will be present.
Implementations
sourceimpl CallbackQueryBuilder
impl CallbackQueryBuilder
pub fn new(id: String, from: User, chat_instance: String) -> Self
sourcepub fn set_message(self, message: Message) -> Self
pub fn set_message(self, message: Message) -> Self
Optional. Message with the callback button that originated the query. Note that message content and message date will not be available if the message is too old
sourcepub fn set_inline_message_id(self, inline_message_id: String) -> Self
pub fn set_inline_message_id(self, inline_message_id: String) -> Self
Optional. Identifier of the message sent via the bot in inline mode, that originated the query.
sourcepub fn set_chat_instance(self, chat_instance: String) -> Self
pub fn set_chat_instance(self, chat_instance: String) -> Self
Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
sourcepub fn set_data(self, data: String) -> Self
pub fn set_data(self, data: String) -> Self
Optional. Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.
sourcepub fn set_game_short_name(self, game_short_name: String) -> Self
pub fn set_game_short_name(self, game_short_name: String) -> Self
Optional. Short name of a Game to be returned, serves as the unique identifier for the game
pub fn build(self) -> CallbackQuery