pub struct ChatShared {
pub request_id: i64,
pub chat_id: i64,
pub title: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
This object contains information about a chat that was shared with the bot using a KeyboardButtonRequestChat button.
Fields
request_id: i64Identifier of the request
chat_id: i64Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.
title: Option<String>Optional. Title of the chat, if the title was requested by the bot.
username: Option<String>Optional. Username of the chat, if the username was requested by the bot and available.
photo: Option<Vec<PhotoSize>>Optional. Available sizes of the chat photo, if the photo was requested by the bot
Implementations
pub fn noskip(self) -> NoSkipChatShared
pub fn new(request_id: i64, chat_id: i64) -> Self
Sourcepub fn get_request_id<'a>(&'a self) -> i64
pub fn get_request_id<'a>(&'a self) -> i64
Identifier of the request
Sourcepub fn set_request_id<'a>(&'a mut self, request_id: i64) -> &'a mut Self
pub fn set_request_id<'a>(&'a mut self, request_id: i64) -> &'a mut Self
Identifier of the request
Sourcepub fn get_chat_id<'a>(&'a self) -> i64
pub fn get_chat_id<'a>(&'a self) -> i64
Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.
Sourcepub fn set_chat_id<'a>(&'a mut self, chat_id: i64) -> &'a mut Self
pub fn set_chat_id<'a>(&'a mut self, chat_id: i64) -> &'a mut Self
Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.
Sourcepub fn get_title<'a>(&'a self) -> Option<&'a str>
pub fn get_title<'a>(&'a self) -> Option<&'a str>
Optional. Title of the chat, if the title was requested by the bot.
Sourcepub fn set_title<'a>(&'a mut self, title: Option<String>) -> &'a mut Self
pub fn set_title<'a>(&'a mut self, title: Option<String>) -> &'a mut Self
Optional. Title of the chat, if the title was requested by the bot.
Sourcepub fn get_username<'a>(&'a self) -> Option<&'a str>
pub fn get_username<'a>(&'a self) -> Option<&'a str>
Optional. Username of the chat, if the username was requested by the bot and available.
Sourcepub fn set_username<'a>(&'a mut self, username: Option<String>) -> &'a mut Self
pub fn set_username<'a>(&'a mut self, username: Option<String>) -> &'a mut Self
Optional. Username of the chat, if the username was requested by the bot and available.