pub struct InlineQuery {
pub id: String,
pub from: BoxWrapper<Unbox<User>>,
pub query: String,
pub offset: String,
pub chat_type: Option<String>,
pub location: Option<BoxWrapper<Unbox<Location>>>,
}Expand description
This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.
Fields
id: StringUnique identifier for this query
from: BoxWrapper<Unbox<User>>Sender
query: StringText of the query (up to 256 characters)
offset: StringOffset of the results to be returned, can be controlled by the bot
chat_type: Option<String>Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat
location: Option<BoxWrapper<Unbox<Location>>>Optional. Sender location, only for bots that request user location
Implementations
Sourceimpl InlineQuery
impl InlineQuery
pub fn noskip(self) -> NoSkipInlineQuery
Sourceimpl InlineQuery
impl InlineQuery
pub fn new<A: Into<User>>( id: String, from: A, query: String, offset: String, ) -> Self
Sourcepub fn set_query<'a>(&'a mut self, query: String) -> &'a mut Self
pub fn set_query<'a>(&'a mut self, query: String) -> &'a mut Self
Text of the query (up to 256 characters)
Sourcepub fn get_offset<'a>(&'a self) -> &'a str
pub fn get_offset<'a>(&'a self) -> &'a str
Offset of the results to be returned, can be controlled by the bot
Sourcepub fn set_offset<'a>(&'a mut self, offset: String) -> &'a mut Self
pub fn set_offset<'a>(&'a mut self, offset: String) -> &'a mut Self
Offset of the results to be returned, can be controlled by the bot
Sourcepub fn get_chat_type<'a>(&'a self) -> Option<&'a str>
pub fn get_chat_type<'a>(&'a self) -> Option<&'a str>
Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat
Sourcepub fn set_chat_type<'a>(
&'a mut self,
chat_type: Option<String>,
) -> &'a mut Self
pub fn set_chat_type<'a>( &'a mut self, chat_type: Option<String>, ) -> &'a mut Self
Optional. Type of the chat from which the inline query was sent. Can be either “sender” for a private chat with the inline query sender, “private”, “group”, “supergroup”, or “channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat
Sourcepub fn get_location<'a>(&'a self) -> Option<&'a Location>
pub fn get_location<'a>(&'a self) -> Option<&'a Location>
Optional. Sender location, only for bots that request user location
Sourcepub fn set_location<'a>(
&'a mut self,
location: Option<Location>,
) -> &'a mut Self
pub fn set_location<'a>( &'a mut self, location: Option<Location>, ) -> &'a mut Self
Optional. Sender location, only for bots that request user location