Invoice

Struct Invoice 

pub struct Invoice {
    pub title: String,
    pub description: String,
    pub start_parameter: String,
    pub currency: String,
    pub total_amount: i64,
}
This object contains basic information about an invoice.

Fields

title: String

Product name

description: String

Product description

start_parameter: String

Unique bot deep-linking parameter that can be used to generate this invoice

currency: String

Three-letter ISO 4217 currency code, or “XTR” for payments in Telegram Stars

total_amount: i64

Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).

Implementations

Source

impl Invoice

pub fn noskip(self) -> NoSkipInvoice

Source

impl Invoice

pub fn new( title: String, description: String, start_parameter: String, currency: String, total_amount: i64, ) -> Self

pub fn get_title<'a>(&'a self) -> &'a str

Product name

pub fn set_title<'a>(&'a mut self, title: String) -> &'a mut Self

Product name

pub fn get_description<'a>(&'a self) -> &'a str

Product description

pub fn set_description<'a>(&'a mut self, description: String) -> &'a mut Self

Product description

pub fn get_start_parameter<'a>(&'a self) -> &'a str

Unique bot deep-linking parameter that can be used to generate this invoice

pub fn set_start_parameter<'a>( &'a mut self, start_parameter: String, ) -> &'a mut Self

Unique bot deep-linking parameter that can be used to generate this invoice

pub fn get_currency<'a>(&'a self) -> &'a str

Three-letter ISO 4217 currency code, or “XTR” for payments in Telegram Stars

pub fn set_currency<'a>(&'a mut self, currency: String) -> &'a mut Self

Three-letter ISO 4217 currency code, or “XTR” for payments in Telegram Stars

pub fn get_total_amount<'a>(&'a self) -> i64

Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).

pub fn set_total_amount<'a>(&'a mut self, total_amount: i64) -> &'a mut Self

Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).