pub struct NoSkipInputStoryContentVideo {
pub tg_type: String,
pub video: String,
pub duration: Option<OrderedFloat<f64>>,
pub cover_frame_timestamp: Option<OrderedFloat<f64>>,
pub is_animation: Option<bool>,
}Expand description
Companion type to InputStoryContentVideo that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
tg_type: StringType of the content, must be video
video: StringThe video to post as a story. The video must be of the size 720x1280, streamable, encoded with H.265 codec, with key frames added each second in the MPEG4 format, and must not exceed 30 MB. The video can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the video was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files: https://core.telegram.org/bots/api#sending-files
duration: Option<OrderedFloat<f64>>cover_frame_timestamp: Option<OrderedFloat<f64>>is_animation: Option<bool>Implementations
Sourceimpl NoSkipInputStoryContentVideo
impl NoSkipInputStoryContentVideo
pub fn skip(self) -> InputStoryContentVideo