pub struct NoSkipLabeledPrice {
pub label: String,
pub amount: i64,
}Expand description
Companion type to LabeledPrice that doesn’t skip fields when serializing. Used for certain deserializers that use arrays to represent struct members
Fields
label: StringPortion label
amount: i64Price of the product in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
Implementations
Sourceimpl NoSkipLabeledPrice
impl NoSkipLabeledPrice
pub fn skip(self) -> LabeledPrice