pub struct ResponseParameters {
pub migrate_to_chat_id: Option<i64>,
pub retry_after: Option<i64>,
}Expand description
Describes why a request was unsuccessful.
Fields
migrate_to_chat_id: Option<i64>Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
retry_after: Option<i64>Optional. In case of exceeding flood control, the number of seconds left to wait before the request can be repeated
Implementations
Sourceimpl ResponseParameters
impl ResponseParameters
pub fn noskip(self) -> NoSkipResponseParameters
Sourceimpl ResponseParameters
impl ResponseParameters
pub fn new() -> Self
Sourcepub fn get_migrate_to_chat_id<'a>(&'a self) -> Option<i64>
pub fn get_migrate_to_chat_id<'a>(&'a self) -> Option<i64>
Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
Sourcepub fn set_migrate_to_chat_id<'a>(
&'a mut self,
migrate_to_chat_id: Option<i64>,
) -> &'a mut Self
pub fn set_migrate_to_chat_id<'a>( &'a mut self, migrate_to_chat_id: Option<i64>, ) -> &'a mut Self
Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
Sourcepub fn get_retry_after<'a>(&'a self) -> Option<i64>
pub fn get_retry_after<'a>(&'a self) -> Option<i64>
Optional. In case of exceeding flood control, the number of seconds left to wait before the request can be repeated
Sourcepub fn set_retry_after<'a>(
&'a mut self,
retry_after: Option<i64>,
) -> &'a mut Self
pub fn set_retry_after<'a>( &'a mut self, retry_after: Option<i64>, ) -> &'a mut Self
Optional. In case of exceeding flood control, the number of seconds left to wait before the request can be repeated