pub struct SuggestedPostPriceBuilder {
pub currency: String,
pub amount: i64,
}Expand description
Describes the price of a suggested post.
Fields
currency: StringCurrency in which the post will be paid. Currently, must be one of “XTR” for Telegram Stars or “TON” for toncoins
amount: i64The amount of the currency that will be paid for the post in the smallest units of the currency, i.e. Telegram Stars or nanotoncoins. Currently, price in Telegram Stars must be between 5 and 100000, and price in nanotoncoins must be between 10000000 and 10000000000000.
Implementations
Sourceimpl SuggestedPostPriceBuilder
impl SuggestedPostPriceBuilder
pub fn new(currency: String, amount: i64) -> Self
Sourcepub fn set_currency(self, currency: String) -> Self
pub fn set_currency(self, currency: String) -> Self
Currency in which the post will be paid. Currently, must be one of “XTR” for Telegram Stars or “TON” for toncoins
Sourcepub fn set_amount(self, amount: i64) -> Self
pub fn set_amount(self, amount: i64) -> Self
The amount of the currency that will be paid for the post in the smallest units of the currency, i.e. Telegram Stars or nanotoncoins. Currently, price in Telegram Stars must be between 5 and 100000, and price in nanotoncoins must be between 10000000 and 10000000000000.
pub fn build(self) -> SuggestedPostPrice